# Based on wxPython
# Copyright: (c) 2018 by Total Control Software
# License:   wxWindows License


def dummy_function(*args, **kwargs):
	return 0


ACCEL_ALT = object
ACCEL_CMD = object
ACCEL_CTRL = object
ACCEL_NORMAL = object
ACCEL_RAW_CTRL = object
ACCEL_SHIFT = object
ACC_EVENT_OBJECT_ACCELERATORCHANGE = 0
ACC_EVENT_OBJECT_CREATE = 0
ACC_EVENT_OBJECT_DEFACTIONCHANGE = 0
ACC_EVENT_OBJECT_DESCRIPTIONCHANGE = 0
ACC_EVENT_OBJECT_DESTROY = 0
ACC_EVENT_OBJECT_FOCUS = 0
ACC_EVENT_OBJECT_HELPCHANGE = 0
ACC_EVENT_OBJECT_HIDE = 0
ACC_EVENT_OBJECT_LOCATIONCHANGE = 0
ACC_EVENT_OBJECT_NAMECHANGE = 0
ACC_EVENT_OBJECT_PARENTCHANGE = 0
ACC_EVENT_OBJECT_REORDER = 0
ACC_EVENT_OBJECT_SELECTION = 0
ACC_EVENT_OBJECT_SELECTIONADD = 0
ACC_EVENT_OBJECT_SELECTIONREMOVE = 0
ACC_EVENT_OBJECT_SELECTIONWITHIN = 0
ACC_EVENT_OBJECT_SHOW = 0
ACC_EVENT_OBJECT_STATECHANGE = 0
ACC_EVENT_OBJECT_VALUECHANGE = 0
ACC_EVENT_SYSTEM_ALERT = 0
ACC_EVENT_SYSTEM_CAPTUREEND = 0
ACC_EVENT_SYSTEM_CAPTURESTART = 0
ACC_EVENT_SYSTEM_CONTEXTHELPEND = 0
ACC_EVENT_SYSTEM_CONTEXTHELPSTART = 0
ACC_EVENT_SYSTEM_DIALOGEND = 0
ACC_EVENT_SYSTEM_DIALOGSTART = 0
ACC_EVENT_SYSTEM_DRAGDROPEND = 0
ACC_EVENT_SYSTEM_DRAGDROPSTART = 0
ACC_EVENT_SYSTEM_FOREGROUND = 0
ACC_EVENT_SYSTEM_MENUEND = 0
ACC_EVENT_SYSTEM_MENUPOPUPEND = 0
ACC_EVENT_SYSTEM_MENUPOPUPSTART = 0
ACC_EVENT_SYSTEM_MENUSTART = 0
ACC_EVENT_SYSTEM_MINIMIZEEND = 0
ACC_EVENT_SYSTEM_MINIMIZESTART = 0
ACC_EVENT_SYSTEM_MOVESIZEEND = 0
ACC_EVENT_SYSTEM_MOVESIZESTART = 0
ACC_EVENT_SYSTEM_SCROLLINGEND = 0
ACC_EVENT_SYSTEM_SCROLLINGSTART = 0
ACC_EVENT_SYSTEM_SOUND = 0
ACC_EVENT_SYSTEM_SWITCHEND = 0
ACC_EVENT_SYSTEM_SWITCHSTART = 0
ACC_FAIL = object
ACC_FALSE = object
ACC_NOT_IMPLEMENTED = object
ACC_NOT_SUPPORTED = object
ACC_OK = object
ACC_SELF = 0
ACC_SEL_ADDSELECTION = object
ACC_SEL_EXTENDSELECTION = object
ACC_SEL_NONE = object
ACC_SEL_REMOVESELECTION = object
ACC_SEL_TAKEFOCUS = object
ACC_SEL_TAKESELECTION = object
ACC_STATE_SYSTEM_ALERT_HIGH = 0
ACC_STATE_SYSTEM_ALERT_LOW = 0
ACC_STATE_SYSTEM_ALERT_MEDIUM = 0
ACC_STATE_SYSTEM_ANIMATED = 0
ACC_STATE_SYSTEM_BUSY = 0
ACC_STATE_SYSTEM_CHECKED = 0
ACC_STATE_SYSTEM_COLLAPSED = 0
ACC_STATE_SYSTEM_DEFAULT = 0
ACC_STATE_SYSTEM_EXPANDED = 0
ACC_STATE_SYSTEM_EXTSELECTABLE = 0
ACC_STATE_SYSTEM_FLOATING = 0
ACC_STATE_SYSTEM_FOCUSABLE = 0
ACC_STATE_SYSTEM_FOCUSED = 0
ACC_STATE_SYSTEM_HOTTRACKED = 0
ACC_STATE_SYSTEM_INVISIBLE = 0
ACC_STATE_SYSTEM_MARQUEED = 0
ACC_STATE_SYSTEM_MIXED = 0
ACC_STATE_SYSTEM_MULTISELECTABLE = 0
ACC_STATE_SYSTEM_OFFSCREEN = 0
ACC_STATE_SYSTEM_PRESSED = 0
ACC_STATE_SYSTEM_PROTECTED = 0
ACC_STATE_SYSTEM_READONLY = 0
ACC_STATE_SYSTEM_SELECTABLE = 0
ACC_STATE_SYSTEM_SELECTED = 0
ACC_STATE_SYSTEM_SELFVOICING = 0
ACC_STATE_SYSTEM_UNAVAILABLE = 0
ADJUST_MINSIZE = 0
ALIGN_BOTTOM = object
ALIGN_CENTER = object
ALIGN_CENTER_HORIZONTAL = object
ALIGN_CENTER_VERTICAL = object
ALIGN_CENTRE = object
ALIGN_CENTRE_HORIZONTAL = object
ALIGN_CENTRE_VERTICAL = object
ALIGN_INVALID = object
ALIGN_LEFT = object
ALIGN_MASK = object
ALIGN_NOT = object
ALIGN_RIGHT = object
ALIGN_TOP = object
ALL = object
ALPHA_OPAQUE = 0
ALPHA_TRANSPARENT = 0
ALWAYS_SHOW_SB = 0
AND = object
AND_INVERT = object
AND_REVERSE = object
ANTIALIAS_DEFAULT = object
ANTIALIAS_NONE = object
APPLY = 0
APP_ASSERT_DIALOG = object
APP_ASSERT_EXCEPTION = object
APP_ASSERT_LOG = object
APP_ASSERT_SUPPRESS = object
ARCH_32 = object
ARCH_64 = object
ARCH_INVALID = object
ARCH_MAX = object
ART_ADD_BOOKMARK = bytes()
ART_BUTTON = bytes()
ART_CDROM = bytes()
ART_CLOSE = bytes()
ART_CMN_DIALOG = bytes()
ART_COPY = bytes()
ART_CROSS_MARK = bytes()
ART_CUT = bytes()
ART_DELETE = bytes()
ART_DEL_BOOKMARK = bytes()
ART_ERROR = bytes()
ART_EXECUTABLE_FILE = bytes()
ART_FILE_OPEN = bytes()
ART_FILE_SAVE = bytes()
ART_FILE_SAVE_AS = bytes()
ART_FIND = bytes()
ART_FIND_AND_REPLACE = bytes()
ART_FLOPPY = bytes()
ART_FOLDER = bytes()
ART_FOLDER_OPEN = bytes()
ART_FRAME_ICON = bytes()
ART_GOTO_FIRST = bytes()
ART_GOTO_LAST = bytes()
ART_GO_BACK = bytes()
ART_GO_DIR_UP = bytes()
ART_GO_DOWN = bytes()
ART_GO_FORWARD = bytes()
ART_GO_HOME = bytes()
ART_GO_TO_PARENT = bytes()
ART_GO_UP = bytes()
ART_HARDDISK = bytes()
ART_HELP = bytes()
ART_HELP_BOOK = bytes()
ART_HELP_BROWSER = bytes()
ART_HELP_FOLDER = bytes()
ART_HELP_PAGE = bytes()
ART_HELP_SETTINGS = bytes()
ART_HELP_SIDE_PANEL = bytes()
ART_INFORMATION = bytes()
ART_LIST = bytes()
ART_LIST_VIEW = bytes()
ART_MENU = bytes()
ART_MESSAGE_BOX = bytes()
ART_MINUS = bytes()
ART_MISSING_IMAGE = bytes()
ART_NEW = bytes()
ART_NEW_DIR = bytes()
ART_NORMAL_FILE = bytes()
ART_OTHER = bytes()
ART_PASTE = bytes()
ART_PLUS = bytes()
ART_PRINT = bytes()
ART_QUESTION = bytes()
ART_QUIT = bytes()
ART_REDO = bytes()
ART_REMOVABLE = bytes()
ART_REPORT_VIEW = bytes()
ART_TICK_MARK = bytes()
ART_TIP = bytes()
ART_TOOLBAR = bytes()
ART_UNDO = bytes()
ART_WARNING = bytes()
Abort = dummy_function
Above = object
Absolute = object
AccObject = object
AccRole = object
AccSelectionFlags = object
AccStatus = object
AcceleratorEntry = object
AcceleratorEntryFlags = object
AcceleratorTable = object
Accessible = object
ActivateEvent = object
AffineMatrix2D = object
AffineMatrix2DBase = object
Alignment = object
AlphaPixelData = object
AlphaPixelData_Accessor = object
AntialiasMode = object
AnyButton = object
App = object
AppAssertMode = object
AppConsole = object
AppTraits = object
Architecture = object
ArchiveFSHandler = object
ArrayVideoModes = object
ArtProvider = object
AsIs = object
AutoBufferedPaintDC = object
AutoBufferedPaintDCFactory = dummy_function
BACKINGSTORE = 0
BACKWARD = 0
BATTERY_CRITICAL_STATE = object
BATTERY_LOW_STATE = object
BATTERY_NORMAL_STATE = object
BATTERY_SHUTDOWN_STATE = object
BATTERY_UNKNOWN_STATE = object
BDIAGONAL_HATCH = 0
BG_STYLE_COLOUR = object
BG_STYLE_CUSTOM = object
BG_STYLE_ERASE = object
BG_STYLE_PAINT = object
BG_STYLE_SYSTEM = object
BG_STYLE_TRANSPARENT = object
BITMAP_SCREEN_DEPTH = 0
BITMAP_TYPE_ANI = object
BITMAP_TYPE_ANY = object
BITMAP_TYPE_BMP = object
BITMAP_TYPE_CUR = object
BITMAP_TYPE_GIF = object
BITMAP_TYPE_ICO = object
BITMAP_TYPE_ICON = object
BITMAP_TYPE_IFF = object
BITMAP_TYPE_INVALID = object
BITMAP_TYPE_JPEG = object
BITMAP_TYPE_MACCURSOR = object
BITMAP_TYPE_PCX = object
BITMAP_TYPE_PICT = object
BITMAP_TYPE_PNG = object
BITMAP_TYPE_PNM = object
BITMAP_TYPE_TGA = object
BITMAP_TYPE_TIF = object
BITMAP_TYPE_TIFF = object
BITMAP_TYPE_XBM = object
BITMAP_TYPE_XBM_DATA = object
BITMAP_TYPE_XPM = object
BITMAP_TYPE_XPM_DATA = object
BI_EXPAND = 0
BK_ALIGN_MASK = 0
BK_BOTTOM = 0
BK_DEFAULT = 0
BK_HITTEST_NOWHERE = 0
BK_HITTEST_ONICON = 0
BK_HITTEST_ONITEM = 0
BK_HITTEST_ONLABEL = 0
BK_HITTEST_ONPAGE = 0
BK_LEFT = 0
BK_RIGHT = 0
BK_TOP = 0
BLACK = object
BLACK_BRUSH = object
BLACK_DASHED_PEN = object
BLACK_PEN = object
BLUE = object
BLUE_BRUSH = object
BLUE_PEN = object
BMP_1BPP = 0
BMP_1BPP_BW = 0
BMP_24BPP = 0
BMP_4BPP = 0
BMP_8BPP = 0
BMP_8BPP_GRAY = 0
BMP_8BPP_GREY = 0
BMP_8BPP_PALETTE = 0
BMP_8BPP_RED = 0
BOLD = 0
BORDER = 0
BORDER_DEFAULT = object
BORDER_DOUBLE = object
BORDER_MASK = object
BORDER_NONE = object
BORDER_RAISED = object
BORDER_SIMPLE = object
BORDER_STATIC = object
BORDER_SUNKEN = object
BORDER_THEME = object
BOTH = object
BOTTOM = object
BRUSHSTYLE_BDIAGONAL_HATCH = object
BRUSHSTYLE_CROSSDIAG_HATCH = object
BRUSHSTYLE_CROSS_HATCH = object
BRUSHSTYLE_FDIAGONAL_HATCH = object
BRUSHSTYLE_FIRST_HATCH = object
BRUSHSTYLE_HORIZONTAL_HATCH = object
BRUSHSTYLE_INVALID = object
BRUSHSTYLE_LAST_HATCH = object
BRUSHSTYLE_SOLID = object
BRUSHSTYLE_STIPPLE = object
BRUSHSTYLE_STIPPLE_MASK = object
BRUSHSTYLE_STIPPLE_MASK_OPAQUE = object
BRUSHSTYLE_TRANSPARENT = object
BRUSHSTYLE_VERTICAL_HATCH = object
BUFFER_CLIENT_AREA = 0
BUFFER_USES_SHARED_BUFFER = 0
BUFFER_VIRTUAL_AREA = 0
BUILD_TYPE = ''
BU_ALIGN_MASK = 0
BU_AUTODRAW = 0
BU_BOTTOM = 0
BU_EXACTFIT = 0
BU_LEFT = 0
BU_NOTEXT = 0
BU_RIGHT = 0
BU_TOP = 0
BackgroundStyle = object
BatteryState = object
BeginBusyCursor = dummy_function
Bell = dummy_function
Below = object
Bitmap = object
BitmapBufferFormat = object
BitmapBufferFormat_ARGB32 = object
BitmapBufferFormat_RGB = object
BitmapBufferFormat_RGB32 = object
BitmapBufferFormat_RGBA = object
BitmapButton = object
BitmapDataObject = object
BitmapFromBuffer = dummy_function
BitmapFromBufferRGBA = dummy_function
BitmapFromImage = dummy_function
BitmapToggleButton = object
BitmapType = object
BookCtrl = object
BookCtrlBase = object
BookCtrlEvent = object
Border = object
Bottom = object
BoxSizer = object
Brush = object
BrushList = object
BrushStyle = object
BufferedDC = object
BufferedPaintDC = object
BusyCursor = object
BusyInfo = object
Button = object
ButtonNameStr = bytes()
C2S_CSS_SYNTAX = 0
C2S_HTML_SYNTAX = 0
C2S_NAME = 0
CANCEL = 0
CANCEL_DEFAULT = 0
CAPTION = 0
CAP_BUTT = object
CAP_INVALID = object
CAP_PROJECTING = object
CAP_ROUND = object
CB_DROPDOWN = 0
CB_READONLY = 0
CB_SIMPLE = 0
CB_SORT = 0
CC_SPECIAL_DCLICK = 0
CC_STD_BUTTON = 0
CENTER = object
CENTRE = object
CHB_ALIGN_MASK = 0
CHB_BOTTOM = 0
CHB_DEFAULT = 0
CHB_LEFT = 0
CHB_RIGHT = 0
CHB_TOP = 0
CHK_2STATE = 0
CHK_3STATE = 0
CHK_ALLOW_3RD_STATE_FOR_USER = 0
CHK_CHECKED = object
CHK_UNCHECKED = object
CHK_UNDETERMINED = object
CHOICEDLG_STYLE = 0
CHOICE_HEIGHT = 0
CHOICE_WIDTH = 0
CLEAR = object
CLIP_CHILDREN = 0
CLIP_SIBLINGS = 0
CLOSE = 0
CLOSE_BOX = 0
CLRP_DEFAULT_STYLE = 0
CLRP_SHOW_LABEL = 0
CLRP_USE_TEXTCTRL = 0
COLOURED = 0
COL_DEFAULT_FLAGS = 0
COL_HIDDEN = 0
COL_REORDERABLE = 0
COL_RESIZABLE = 0
COL_SORTABLE = 0
COL_WIDTH_AUTOSIZE = 0
COL_WIDTH_DEFAULT = 0
COMPOSITION_ADD = object
COMPOSITION_ATOP = object
COMPOSITION_CLEAR = object
COMPOSITION_DEST = object
COMPOSITION_DEST_ATOP = object
COMPOSITION_DEST_IN = object
COMPOSITION_DEST_OUT = object
COMPOSITION_DEST_OVER = object
COMPOSITION_IN = object
COMPOSITION_INVALID = object
COMPOSITION_OUT = object
COMPOSITION_OVER = object
COMPOSITION_SOURCE = object
COMPOSITION_XOR = object
CONFIG_USE_GLOBAL_FILE = 0
CONFIG_USE_LOCAL_FILE = 0
CONFIG_USE_NO_ESCAPE_CHARACTERS = 0
CONFIG_USE_RELATIVE_PATH = 0
CONFIG_USE_SUBDIR = 0
CONTROL_CHECKABLE = 0
CONTROL_CHECKED = 0
CONTROL_CURRENT = 0
CONTROL_DISABLED = 0
CONTROL_EXPANDED = 0
CONTROL_FLAT = 0
CONTROL_FOCUSED = 0
CONTROL_ISDEFAULT = 0
CONTROL_ISSUBMENU = 0
CONTROL_PRESSED = 0
CONTROL_SELECTED = 0
CONTROL_SIZEGRIP = 0
CONTROL_SPECIAL = 0
CONTROL_UNDETERMINED = 0
COPY = object
CP_DEFAULT_STYLE = 0
CP_NO_TLW_RESIZE = 0
CROSSDIAG_HATCH = 0
CROSS_CURSOR = object
CROSS_HATCH = 0
CURSOR_ARROW = object
CURSOR_ARROWWAIT = object
CURSOR_BLANK = object
CURSOR_BULLSEYE = object
CURSOR_CHAR = object
CURSOR_COPY_ARROW = object
CURSOR_CROSS = object
CURSOR_DEFAULT = object
CURSOR_HAND = object
CURSOR_IBEAM = object
CURSOR_LEFT_BUTTON = object
CURSOR_MAGNIFIER = object
CURSOR_MAX = object
CURSOR_MIDDLE_BUTTON = object
CURSOR_NONE = object
CURSOR_NO_ENTRY = object
CURSOR_PAINT_BRUSH = object
CURSOR_PENCIL = object
CURSOR_POINT_LEFT = object
CURSOR_POINT_RIGHT = object
CURSOR_QUESTION_ARROW = object
CURSOR_RIGHT_ARROW = object
CURSOR_RIGHT_BUTTON = object
CURSOR_SIZENESW = object
CURSOR_SIZENS = object
CURSOR_SIZENWSE = object
CURSOR_SIZEWE = object
CURSOR_SIZING = object
CURSOR_SPRAYCAN = object
CURSOR_WAIT = object
CURSOR_WATCH = object
CYAN = object
CYAN_BRUSH = object
CYAN_PEN = object
CallAfter = dummy_function
CallLater = object
Caret = object
Center = object
Centre = object
CentreX = object
CentreY = object
CheckBox = object
CheckBoxNameStr = bytes()
CheckBoxState = object
CheckListBox = object
ChildFocusEvent = object
Choice = object
ChoiceNameStr = bytes()
Choicebook = object
ClassInfo = object
ClientDC = object
ClientDataContainer = object
ClientDisplayRect = dummy_function
Clipboard = object
ClipboardTextEvent = object
CloseEvent = object
CollapsiblePane = object
CollapsiblePaneEvent = object
CollapsiblePaneNameStr = bytes()
Colour = object
ColourData = object
ColourDatabase = object
ColourDialog = object
ColourDisplay = dummy_function
ColourPickerCtrl = object
ColourPickerCtrlNameStr = bytes()
ColourPickerEvent = object
ColourPickerWidgetNameStr = bytes()
ComboBox = object
ComboBoxNameStr = bytes()
ComboCtrl = object
ComboCtrlFeatures = object
ComboPopup = object
Command = object
CommandEvent = object
CommandList = object
CommandList_iterator = object
CommandProcessor = object
CompositionMode = object
Config = object
ConfigBase = object
ConfigPathChanger = object
ContextHelp = object
ContextHelpButton = object
ContextMenuEvent = object
Control = object
ControlNameStr = bytes()
ControlWithItems = object
Cursor = object
CursorFromImage = object
CustomDataFormat = dummy_function
CustomDataObject = object
DC = object
DCBrushChanger = object
DCClipper = object
DCFontChanger = object
DCOverlay = object
DCPenChanger = object
DCTextColourChanger = object
DD_CHANGE_DIR = 0
DD_DEFAULT_STYLE = 0
DD_DIR_MUST_EXIST = 0
DD_NEW_DIR_BUTTON = 0
DECORATIVE = 0
DEFAULT = 0
DEFAULT_DIALOG_STYLE = 0
DEFAULT_FRAME_STYLE = 0
DF_BITMAP = object
DF_DIB = object
DF_DIF = object
DF_ENHMETAFILE = object
DF_FILENAME = object
DF_HTML = object
DF_INVALID = object
DF_LOCALE = object
DF_MAX = object
DF_METAFILE = object
DF_OEMTEXT = object
DF_PALETTE = object
DF_PENDATA = object
DF_PRIVATE = object
DF_RIFF = object
DF_SYLK = object
DF_TEXT = object
DF_TIFF = object
DF_UNICODETEXT = object
DF_WAVE = object
DIALOG_ADAPTATION_ANY_SIZER = 0
DIALOG_ADAPTATION_LOOSE_BUTTONS = 0
DIALOG_ADAPTATION_MODE_DEFAULT = object
DIALOG_ADAPTATION_MODE_DISABLED = object
DIALOG_ADAPTATION_MODE_ENABLED = object
DIALOG_ADAPTATION_NONE = 0
DIALOG_ADAPTATION_STANDARD_SIZER = 0
DIALOG_EX_CONTEXTHELP = 0
DIALOG_EX_METAL = 0
DIALOG_NO_PARENT = 0
DIRCTRL_3D_INTERNAL = 0
DIRCTRL_DIR_ONLY = 0
DIRCTRL_EDIT_LABELS = 0
DIRCTRL_MULTIPLE = 0
DIRCTRL_SELECT_FIRST = 0
DIRCTRL_SHOW_FILTERS = 0
DIRECTION_MASK = object
DIRP_CHANGE_DIR = 0
DIRP_DEFAULT_STYLE = 0
DIRP_DIR_MUST_EXIST = 0
DIRP_SMALL = 0
DIRP_USE_TEXTCTRL = 0
DLG_PNT = dummy_function
DLG_SZE = dummy_function
DLG_UNIT = dummy_function
DOT = 0
DOT_DASH = 0
DOUBLE_BORDER = 0
DOWN = object
DUPLEX_HORIZONTAL = object
DUPLEX_SIMPLEX = object
DUPLEX_VERTICAL = object
DashCArrayHolder = object
DataFormat = object
DataFormatId = object
DataObject = object
DataObjectComposite = object
DataObjectSimple = object
DateSpan = object
DateTime = object
DateTimeFromDMY = dummy_function
DateTimeFromHMS = dummy_function
DateTimeFromJDN = dummy_function
DateTimeFromTimeT = dummy_function
DefaultCoord = 0
DefaultDateTime = object
DefaultDateTimeFormat = bytes()
DefaultPosition = object
DefaultSize = object
DefaultSpan = object
DefaultTimeSpanFormat = bytes()
DefaultValidator = object
DefaultVideoMode = object
DelegateRendererNative = object
Dialog = object
DialogLayoutAdaptationMode = object
DialogLayoutAdapter = object
DialogNameStr = bytes()
DirDialog = object
DirDialogDefaultFolderStr = bytes()
DirDialogNameStr = bytes()
DirFilterListCtrl = object
DirPickerCtrl = object
DirPickerCtrlNameStr = bytes()
DirPickerWidgetLabel = bytes()
DirPickerWidgetNameStr = bytes()
DirSelector = dummy_function
DirSelectorPromptStr = bytes()
Direction = object
DisableAsserts = dummy_function
Display = object
DisplayChangedEvent = object
DisplayDepth = dummy_function
DisplaySize = dummy_function
DisplaySizeMM = dummy_function
DragCancel = object
DragCopy = object
DragError = object
DragImage = object
DragLink = object
DragMove = object
DragNone = object
DragResult = object
Drag_AllowMove = 0
Drag_CopyOnly = 0
Drag_DefaultMove = 0
DropFilesEvent = object
DropSource = object
DropTarget = object
DuplexMode = object
EAST = object
ELLIPSIZE_END = object
ELLIPSIZE_FLAGS_DEFAULT = object
ELLIPSIZE_FLAGS_EXPAND_TABS = object
ELLIPSIZE_FLAGS_NONE = object
ELLIPSIZE_FLAGS_PROCESS_MNEMONICS = object
ELLIPSIZE_MIDDLE = object
ELLIPSIZE_NONE = object
ELLIPSIZE_START = object
ENDIAN_BIG = object
ENDIAN_INVALID = object
ENDIAN_LITTLE = object
ENDIAN_MAX = object
ENDIAN_PDP = object
EQUIV = object
EVENT_PROPAGATE_MAX = object
EVENT_PROPAGATE_NONE = object
EVT_ACTIVATE = object
EVT_ACTIVATE_APP = object
EVT_BOOKCTRL_PAGE_CHANGED = object
EVT_BOOKCTRL_PAGE_CHANGING = object
EVT_BUTTON = object
EVT_CATEGORY_ALL = object
EVT_CATEGORY_SOCKET = object
EVT_CATEGORY_THREAD = object
EVT_CATEGORY_TIMER = object
EVT_CATEGORY_UI = object
EVT_CATEGORY_USER_INPUT = object
EVT_CHAR = object
EVT_CHAR_HOOK = object
EVT_CHECKBOX = object
EVT_CHECKLISTBOX = object
EVT_CHILD_FOCUS = object
EVT_CHOICE = object
EVT_CHOICEBOOK_PAGE_CHANGED = object
EVT_CHOICEBOOK_PAGE_CHANGING = object
EVT_CLOSE = object
EVT_COLLAPSIBLEPANE_CHANGED = object
EVT_COLOURPICKER_CHANGED = object
EVT_COMBOBOX = object
EVT_COMBOBOX_CLOSEUP = object
EVT_COMBOBOX_DROPDOWN = object
EVT_COMMAND_ENTER = object
EVT_COMMAND_KILL_FOCUS = object
EVT_COMMAND_LEFT_CLICK = object
EVT_COMMAND_LEFT_DCLICK = object
EVT_COMMAND_RIGHT_CLICK = object
EVT_COMMAND_RIGHT_DCLICK = object
EVT_COMMAND_SCROLL = object
EVT_COMMAND_SCROLL_BOTTOM = object
EVT_COMMAND_SCROLL_CHANGED = object
EVT_COMMAND_SCROLL_ENDSCROLL = object
EVT_COMMAND_SCROLL_LINEDOWN = object
EVT_COMMAND_SCROLL_LINEUP = object
EVT_COMMAND_SCROLL_PAGEDOWN = object
EVT_COMMAND_SCROLL_PAGEUP = object
EVT_COMMAND_SCROLL_THUMBRELEASE = object
EVT_COMMAND_SCROLL_THUMBTRACK = object
EVT_COMMAND_SCROLL_TOP = object
EVT_COMMAND_SET_FOCUS = object
EVT_CONTEXT_MENU = object
EVT_DETAILED_HELP = object
EVT_DETAILED_HELP_RANGE = object
EVT_DIRCTRL_FILEACTIVATED = object
EVT_DIRCTRL_SELECTIONCHANGED = object
EVT_DIRPICKER_CHANGED = object
EVT_DISPLAY_CHANGED = object
EVT_DROP_FILES = object
EVT_END_PROCESS = object
EVT_END_SESSION = object
EVT_ENTER_WINDOW = object
EVT_ERASE_BACKGROUND = object
EVT_FILECTRL_FILEACTIVATED = object
EVT_FILECTRL_FILTERCHANGED = object
EVT_FILECTRL_FOLDERCHANGED = object
EVT_FILECTRL_SELECTIONCHANGED = object
EVT_FILEPICKER_CHANGED = object
EVT_FIND = object
EVT_FIND_CLOSE = object
EVT_FIND_NEXT = object
EVT_FIND_REPLACE = object
EVT_FIND_REPLACE_ALL = object
EVT_FONTPICKER_CHANGED = object
EVT_FSWATCHER = object
EVT_HEADER_BEGIN_REORDER = object
EVT_HEADER_BEGIN_RESIZE = object
EVT_HEADER_CLICK = object
EVT_HEADER_DCLICK = object
EVT_HEADER_DRAGGING_CANCELLED = object
EVT_HEADER_END_REORDER = object
EVT_HEADER_END_RESIZE = object
EVT_HEADER_MIDDLE_CLICK = object
EVT_HEADER_MIDDLE_DCLICK = object
EVT_HEADER_RESIZING = object
EVT_HEADER_RIGHT_CLICK = object
EVT_HEADER_RIGHT_DCLICK = object
EVT_HEADER_SEPARATOR_DCLICK = object
EVT_HELP = object
EVT_HELP_RANGE = object
EVT_HIBERNATE = object
EVT_HOTKEY = object
EVT_ICONIZE = object
EVT_IDLE = object
EVT_INIT_DIALOG = object
EVT_JOYSTICK_EVENTS = object
EVT_JOY_BUTTON_DOWN = object
EVT_JOY_BUTTON_UP = object
EVT_JOY_MOVE = object
EVT_JOY_ZMOVE = object
EVT_KEY_DOWN = object
EVT_KEY_UP = object
EVT_KILL_FOCUS = object
EVT_LEAVE_WINDOW = object
EVT_LEFT_DCLICK = object
EVT_LEFT_DOWN = object
EVT_LEFT_UP = object
EVT_LISTBOOK_PAGE_CHANGED = object
EVT_LISTBOOK_PAGE_CHANGING = object
EVT_LISTBOX = object
EVT_LISTBOX_DCLICK = object
EVT_LIST_BEGIN_DRAG = object
EVT_LIST_BEGIN_LABEL_EDIT = object
EVT_LIST_BEGIN_RDRAG = object
EVT_LIST_CACHE_HINT = object
EVT_LIST_COL_BEGIN_DRAG = object
EVT_LIST_COL_CLICK = object
EVT_LIST_COL_DRAGGING = object
EVT_LIST_COL_END_DRAG = object
EVT_LIST_COL_RIGHT_CLICK = object
EVT_LIST_DELETE_ALL_ITEMS = object
EVT_LIST_DELETE_ITEM = object
EVT_LIST_END_LABEL_EDIT = object
EVT_LIST_INSERT_ITEM = object
EVT_LIST_ITEM_ACTIVATED = object
EVT_LIST_ITEM_DESELECTED = object
EVT_LIST_ITEM_FOCUSED = object
EVT_LIST_ITEM_MIDDLE_CLICK = object
EVT_LIST_ITEM_RIGHT_CLICK = object
EVT_LIST_ITEM_SELECTED = object
EVT_LIST_KEY_DOWN = object
EVT_MAXIMIZE = object
EVT_MENU = object
EVT_MENU_CLOSE = object
EVT_MENU_HIGHLIGHT = object
EVT_MENU_HIGHLIGHT_ALL = object
EVT_MENU_OPEN = object
EVT_MENU_RANGE = object
EVT_MIDDLE_DCLICK = object
EVT_MIDDLE_DOWN = object
EVT_MIDDLE_UP = object
EVT_MOTION = object
EVT_MOUSEWHEEL = object
EVT_MOUSE_AUX1_DCLICK = object
EVT_MOUSE_AUX1_DOWN = object
EVT_MOUSE_AUX1_UP = object
EVT_MOUSE_AUX2_DCLICK = object
EVT_MOUSE_AUX2_DOWN = object
EVT_MOUSE_AUX2_UP = object
EVT_MOUSE_CAPTURE_CHANGED = object
EVT_MOUSE_CAPTURE_LOST = object
EVT_MOUSE_EVENTS = object
EVT_MOVE = object
EVT_MOVE_END = object
EVT_MOVE_START = object
EVT_MOVING = object
EVT_NAVIGATION_KEY = object
EVT_NC_PAINT = object
EVT_NOTEBOOK_PAGE_CHANGED = object
EVT_NOTEBOOK_PAGE_CHANGING = object
EVT_PAINT = object
EVT_PALETTE_CHANGED = object
EVT_POWER_RESUME = object
EVT_POWER_SUSPENDED = object
EVT_POWER_SUSPENDING = object
EVT_POWER_SUSPEND_CANCEL = object
EVT_QUERY_END_SESSION = object
EVT_QUERY_NEW_PALETTE = object
EVT_RADIOBOX = object
EVT_RADIOBUTTON = object
EVT_RIGHT_DCLICK = object
EVT_RIGHT_DOWN = object
EVT_RIGHT_UP = object
EVT_SCROLL = object
EVT_SCROLLBAR = object
EVT_SCROLLWIN = object
EVT_SCROLLWIN_BOTTOM = object
EVT_SCROLLWIN_LINEDOWN = object
EVT_SCROLLWIN_LINEUP = object
EVT_SCROLLWIN_PAGEDOWN = object
EVT_SCROLLWIN_PAGEUP = object
EVT_SCROLLWIN_THUMBRELEASE = object
EVT_SCROLLWIN_THUMBTRACK = object
EVT_SCROLLWIN_TOP = object
EVT_SCROLL_BOTTOM = object
EVT_SCROLL_CHANGED = object
EVT_SCROLL_ENDSCROLL = object
EVT_SCROLL_LINEDOWN = object
EVT_SCROLL_LINEUP = object
EVT_SCROLL_PAGEDOWN = object
EVT_SCROLL_PAGEUP = object
EVT_SCROLL_THUMBRELEASE = object
EVT_SCROLL_THUMBTRACK = object
EVT_SCROLL_TOP = object
EVT_SEARCHCTRL_CANCEL_BTN = object
EVT_SEARCHCTRL_SEARCH_BTN = object
EVT_SET_CURSOR = object
EVT_SET_FOCUS = object
EVT_SHOW = object
EVT_SIZE = object
EVT_SIZING = object
EVT_SLIDER = object
EVT_SPIN = object
EVT_SPINCTRL = object
EVT_SPINCTRLDOUBLE = object
EVT_SPIN_DOWN = object
EVT_SPIN_UP = object
EVT_SPLITTER_DCLICK = object
EVT_SPLITTER_DOUBLECLICKED = object
EVT_SPLITTER_SASH_POS_CHANGED = object
EVT_SPLITTER_SASH_POS_CHANGING = object
EVT_SPLITTER_UNSPLIT = object
EVT_SYS_COLOUR_CHANGED = object
EVT_TEXT = object
EVT_TEXT_COPY = object
EVT_TEXT_CUT = object
EVT_TEXT_ENTER = object
EVT_TEXT_MAXLEN = object
EVT_TEXT_PASTE = object
EVT_TEXT_URL = object
EVT_THREAD = object
EVT_TIMER = object
EVT_TOGGLEBUTTON = object
EVT_TOOL = object
EVT_TOOLBOOK_PAGE_CHANGED = object
EVT_TOOLBOOK_PAGE_CHANGING = object
EVT_TOOL_DROPDOWN = object
EVT_TOOL_ENTER = object
EVT_TOOL_RANGE = object
EVT_TOOL_RCLICKED = object
EVT_TOOL_RCLICKED_RANGE = object
EVT_TREEBOOK_NODE_COLLAPSED = object
EVT_TREEBOOK_NODE_EXPANDED = object
EVT_TREEBOOK_PAGE_CHANGED = object
EVT_TREEBOOK_PAGE_CHANGING = object
EVT_TREE_BEGIN_DRAG = object
EVT_TREE_BEGIN_LABEL_EDIT = object
EVT_TREE_BEGIN_RDRAG = object
EVT_TREE_DELETE_ITEM = object
EVT_TREE_END_DRAG = object
EVT_TREE_END_LABEL_EDIT = object
EVT_TREE_GET_INFO = object
EVT_TREE_ITEM_ACTIVATED = object
EVT_TREE_ITEM_COLLAPSED = object
EVT_TREE_ITEM_COLLAPSING = object
EVT_TREE_ITEM_EXPANDED = object
EVT_TREE_ITEM_EXPANDING = object
EVT_TREE_ITEM_GETTOOLTIP = object
EVT_TREE_ITEM_MENU = object
EVT_TREE_ITEM_MIDDLE_CLICK = object
EVT_TREE_ITEM_RIGHT_CLICK = object
EVT_TREE_KEY_DOWN = object
EVT_TREE_SEL_CHANGED = object
EVT_TREE_SEL_CHANGING = object
EVT_TREE_SET_INFO = object
EVT_TREE_STATE_IMAGE_CLICK = object
EVT_UPDATE_UI = object
EVT_UPDATE_UI_RANGE = object
EVT_VLBOX = object
EVT_WINDOW_CREATE = object
EVT_WINDOW_DESTROY = object
EVT_WINDOW_MODAL_DIALOG_CLOSED = object
EXEC_ASYNC = 0
EXEC_BLOCK = 0
EXEC_HIDE_CONSOLE = 0
EXEC_MAKE_GROUP_LEADER = 0
EXEC_NODISABLE = 0
EXEC_NOEVENTS = 0
EXEC_SHOW_CONSOLE = 0
EXEC_SYNC = 0
EXPAND = object
EXTEND_LAST_ON_EACH_LINE = 0
Edge = object
EllipsizeFlags = object
EllipsizeMode = object
EmptyBitmap = dummy_function
EmptyBitmapRGBA = dummy_function
EmptyIcon = dummy_function
EmptyImage = dummy_function
EmptyString = ''
EnableTopLevelWindows = dummy_function
EndBusyCursor = dummy_function
Endianness = object
EraseEvent = object
Event = object
EventBlocker = object
EventCategory = object
EventFilter = object
EventLoop = object
EventLoopActivator = object
EventLoopBase = object
EventPropagation = object
EvtHandler = object
Execute = dummy_function
ExecuteEnv = object
Exit = dummy_function
FC_DEFAULT_STYLE = 0
FC_MULTIPLE = 0
FC_NOSHOWHIDDEN = 0
FC_OPEN = 0
FC_SAVE = 0
FDIAGONAL_HATCH = 0
FD_CHANGE_DIR = 0
FD_DEFAULT_STYLE = 0
FD_FILE_MUST_EXIST = 0
FD_MULTIPLE = 0
FD_OPEN = 0
FD_OVERWRITE_PROMPT = 0
FD_PREVIEW = 0
FD_SAVE = 0
FFont = dummy_function
FIXED_LENGTH = 0
FIXED_MINSIZE = object
FLEX_GROWMODE_ALL = object
FLEX_GROWMODE_NONE = object
FLEX_GROWMODE_SPECIFIED = object
FLOOD_BORDER = object
FLOOD_SURFACE = object
FLP_CHANGE_DIR = 0
FLP_DEFAULT_STYLE = 0
FLP_FILE_MUST_EXIST = 0
FLP_OPEN = 0
FLP_OVERWRITE_PROMPT = 0
FLP_SAVE = 0
FLP_SMALL = 0
FLP_USE_TEXTCTRL = 0
FNTP_DEFAULT_STYLE = 0
FNTP_FONTDESC_AS_LABEL = 0
FNTP_USEFONT_FOR_LABEL = 0
FNTP_USE_TEXTCTRL = 0
FONTBTN_DEFAULT_STYLE = 0
FONTENCODING_ALTERNATIVE = object
FONTENCODING_BIG5 = object
FONTENCODING_BULGARIAN = object
FONTENCODING_CP1250 = object
FONTENCODING_CP1251 = object
FONTENCODING_CP1252 = object
FONTENCODING_CP1253 = object
FONTENCODING_CP1254 = object
FONTENCODING_CP1255 = object
FONTENCODING_CP1256 = object
FONTENCODING_CP1257 = object
FONTENCODING_CP1258 = object
FONTENCODING_CP12_MAX = object
FONTENCODING_CP1361 = object
FONTENCODING_CP437 = object
FONTENCODING_CP850 = object
FONTENCODING_CP852 = object
FONTENCODING_CP855 = object
FONTENCODING_CP866 = object
FONTENCODING_CP874 = object
FONTENCODING_CP932 = object
FONTENCODING_CP936 = object
FONTENCODING_CP949 = object
FONTENCODING_CP950 = object
FONTENCODING_DEFAULT = object
FONTENCODING_EUC_JP = object
FONTENCODING_EUC_KR = object
FONTENCODING_GB2312 = object
FONTENCODING_ISO2022_JP = object
FONTENCODING_ISO8859_1 = object
FONTENCODING_ISO8859_10 = object
FONTENCODING_ISO8859_11 = object
FONTENCODING_ISO8859_12 = object
FONTENCODING_ISO8859_13 = object
FONTENCODING_ISO8859_14 = object
FONTENCODING_ISO8859_15 = object
FONTENCODING_ISO8859_2 = object
FONTENCODING_ISO8859_3 = object
FONTENCODING_ISO8859_4 = object
FONTENCODING_ISO8859_5 = object
FONTENCODING_ISO8859_6 = object
FONTENCODING_ISO8859_7 = object
FONTENCODING_ISO8859_8 = object
FONTENCODING_ISO8859_9 = object
FONTENCODING_ISO8859_MAX = object
FONTENCODING_JOHAB = object
FONTENCODING_KOI8 = object
FONTENCODING_KOI8_U = object
FONTENCODING_MACARABIC = object
FONTENCODING_MACARABICEXT = object
FONTENCODING_MACARMENIAN = object
FONTENCODING_MACBENGALI = object
FONTENCODING_MACBURMESE = object
FONTENCODING_MACCELTIC = object
FONTENCODING_MACCENTRALEUR = object
FONTENCODING_MACCHINESESIMP = object
FONTENCODING_MACCHINESETRAD = object
FONTENCODING_MACCROATIAN = object
FONTENCODING_MACCYRILLIC = object
FONTENCODING_MACDEVANAGARI = object
FONTENCODING_MACDINGBATS = object
FONTENCODING_MACETHIOPIC = object
FONTENCODING_MACGAELIC = object
FONTENCODING_MACGEORGIAN = object
FONTENCODING_MACGREEK = object
FONTENCODING_MACGUJARATI = object
FONTENCODING_MACGURMUKHI = object
FONTENCODING_MACHEBREW = object
FONTENCODING_MACICELANDIC = object
FONTENCODING_MACJAPANESE = object
FONTENCODING_MACKANNADA = object
FONTENCODING_MACKEYBOARD = object
FONTENCODING_MACKHMER = object
FONTENCODING_MACKOREAN = object
FONTENCODING_MACLAOTIAN = object
FONTENCODING_MACMALAJALAM = object
FONTENCODING_MACMAX = object
FONTENCODING_MACMIN = object
FONTENCODING_MACMONGOLIAN = object
FONTENCODING_MACORIYA = object
FONTENCODING_MACROMAN = object
FONTENCODING_MACROMANIAN = object
FONTENCODING_MACSINHALESE = object
FONTENCODING_MACSYMBOL = object
FONTENCODING_MACTAMIL = object
FONTENCODING_MACTELUGU = object
FONTENCODING_MACTHAI = object
FONTENCODING_MACTIBETAN = object
FONTENCODING_MACTURKISH = object
FONTENCODING_MACVIATNAMESE = object
FONTENCODING_MAX = object
FONTENCODING_SHIFT_JIS = object
FONTENCODING_SYSTEM = object
FONTENCODING_UNICODE = object
FONTENCODING_UTF16 = object
FONTENCODING_UTF16BE = object
FONTENCODING_UTF16LE = object
FONTENCODING_UTF32 = object
FONTENCODING_UTF32BE = object
FONTENCODING_UTF32LE = object
FONTENCODING_UTF7 = object
FONTENCODING_UTF8 = object
FONTENCODING_VIETNAMESE = object
FONTFAMILY_DECORATIVE = object
FONTFAMILY_DEFAULT = object
FONTFAMILY_MAX = object
FONTFAMILY_MODERN = object
FONTFAMILY_ROMAN = object
FONTFAMILY_SCRIPT = object
FONTFAMILY_SWISS = object
FONTFAMILY_TELETYPE = object
FONTFAMILY_UNKNOWN = object
FONTFLAG_ANTIALIASED = object
FONTFLAG_BOLD = object
FONTFLAG_DEFAULT = object
FONTFLAG_ITALIC = object
FONTFLAG_LIGHT = object
FONTFLAG_MASK = object
FONTFLAG_NOT_ANTIALIASED = object
FONTFLAG_SLANT = object
FONTFLAG_STRIKETHROUGH = object
FONTFLAG_UNDERLINED = object
FONTSIZE_LARGE = object
FONTSIZE_MEDIUM = object
FONTSIZE_SMALL = object
FONTSIZE_XX_LARGE = object
FONTSIZE_XX_SMALL = object
FONTSIZE_X_LARGE = object
FONTSIZE_X_SMALL = object
FONTSTYLE_ITALIC = object
FONTSTYLE_MAX = object
FONTSTYLE_NORMAL = object
FONTSTYLE_SLANT = object
FONTWEIGHT_BOLD = object
FONTWEIGHT_LIGHT = object
FONTWEIGHT_MAX = object
FONTWEIGHT_NORMAL = object
FORWARD = 0
FRAME_DRAWER = 0
FRAME_EX_CONTEXTHELP = 0
FRAME_EX_METAL = 0
FRAME_FLOAT_ON_PARENT = 0
FRAME_NO_TASKBAR = 0
FRAME_NO_WINDOW_MENU = 0
FRAME_SHAPED = 0
FRAME_TOOL_WINDOW = 0
FR_DOWN = object
FR_MATCHCASE = object
FR_NOMATCHCASE = object
FR_NOUPDOWN = object
FR_NOWHOLEWORD = object
FR_REPLACEDIALOG = object
FR_WHOLEWORD = object
FSFile = object
FSWFlags = object
FSWWarningType = object
FSW_EVENT_ACCESS = object
FSW_EVENT_ALL = object
FSW_EVENT_ATTRIB = object
FSW_EVENT_CREATE = object
FSW_EVENT_DELETE = object
FSW_EVENT_ERROR = object
FSW_EVENT_MODIFY = object
FSW_EVENT_RENAME = object
FSW_EVENT_UNMOUNT = object
FSW_EVENT_WARNING = object
FSW_WARNING_GENERAL = object
FSW_WARNING_NONE = object
FSW_WARNING_OVERFLOW = object
FS_READ = object
FS_SEEKABLE = object
FULLSCREEN_ALL = 0
FULLSCREEN_NOBORDER = 0
FULLSCREEN_NOCAPTION = 0
FULLSCREEN_NOMENUBAR = 0
FULLSCREEN_NOSTATUSBAR = 0
FULLSCREEN_NOTOOLBAR = 0
FULL_REPAINT_ON_RESIZE = 0
FileConfig = object
FileCtrl = object
FileCtrlEvent = object
FileCtrlNameStr = bytes()
FileDataObject = object
FileDialog = object
FileDialogNameStr = bytes()
FileDirPickerEvent = object
FileDropTarget = object
FileHistory = object
FileHistoryMenuList = object
FileHistoryMenuList_iterator = object
FilePickerCtrl = object
FilePickerCtrlNameStr = bytes()
FilePickerWidgetLabel = bytes()
FilePickerWidgetNameStr = bytes()
FileSelector = dummy_function
FileSelectorDefaultWildcardStr = bytes()
FileSelectorEx = dummy_function
FileSelectorPromptStr = bytes()
FileSystem = object
FileSystemHandler = object
FileSystemOpenFlags = object
FileSystemWatcher = object
FileSystemWatcherEvent = object
FileTranslationsLoader = object
FileType = object
FileTypeInfo = object
FilterFSHandler = object
FindDialogEvent = object
FindMenuItemId = dummy_function
FindReplaceData = object
FindReplaceDialog = object
FindReplaceDialogStyles = object
FindReplaceFlags = object
FindWindowAtPoint = dummy_function
FindWindowAtPointer = dummy_function
FindWindowById = dummy_function
FindWindowByLabel = dummy_function
FindWindowByName = dummy_function
FlexGridSizer = object
FlexSizerGrowMode = object
FloodFillStyle = object
FocusEvent = object
Font = object
FontData = object
FontDialog = object
FontEncoding = object
FontEnumerator = object
FontFamily = object
FontFlag = object
FontInfo = object
FontList = object
FontMapper = object
FontMetrics = object
FontPickerCtrl = object
FontPickerCtrlNameStr = bytes()
FontPickerEvent = object
FontPickerWidgetNameStr = bytes()
FontStyle = object
FontSymbolicSize = object
FontWeight = object
FormatInvalid = object
Frame = object
FrameNameStr = bytes()
FromCurrent = object
FromEnd = object
FromStart = object
FrozenWindow = object
FutureCall = object
GA_HORIZONTAL = 0
GA_SMOOTH = 0
GA_VERTICAL = 0
GBPosition = object
GBSizerItem = object
GBSpan = object
GCDC = object
GDIObject = object
GIFHandler = object
GREEN = object
GREEN_BRUSH = object
GREEN_PEN = object
GREY_BRUSH = object
GREY_PEN = object
GROW = object
GUIEventLoop = object
Gauge = object
GaugeNameStr = bytes()
GenericDirCtrl = object
GenericDragImage = object
GenericMessageDialog = object
GenericProgressDialog = object
GeometryCentre = object
GetAccelFromString = dummy_function
GetActiveWindow = dummy_function
GetApp = dummy_function
GetBatteryState = dummy_function
GetClientDisplayRect = dummy_function
GetColourFromUser = dummy_function
GetDefaultPyEncoding = dummy_function
GetDisplayPPI = dummy_function
GetDisplaySize = dummy_function
GetDisplaySizeMM = dummy_function
GetEmailAddress = dummy_function
GetFontFromUser = dummy_function
GetFullHostName = dummy_function
GetHomeDir = dummy_function
GetHostName = dummy_function
GetKeyState = dummy_function
GetLibraryVersionInfo = dummy_function
GetLocale = dummy_function
GetMousePosition = dummy_function
GetMouseState = dummy_function
GetNumberFromUser = dummy_function
GetOsDescription = dummy_function
GetOsVersion = dummy_function
GetPasswordFromUser = dummy_function
GetPasswordFromUserPromptStr = bytes()
GetPowerType = dummy_function
GetProcessId = dummy_function
GetSingleChoice = dummy_function
GetStockLabel = dummy_function
GetTextFromUser = dummy_function
GetTextFromUserPromptStr = bytes()
GetTopLevelParent = dummy_function
GetTopLevelWindows = dummy_function
GetTranslation = dummy_function
GetUserHome = dummy_function
GetUserId = dummy_function
GetUserName = dummy_function
GraphicsBitmap = object
GraphicsBrush = object
GraphicsContext = object
GraphicsFont = object
GraphicsGradientStop = object
GraphicsGradientStops = object
GraphicsMatrix = object
GraphicsObject = object
GraphicsPath = object
GraphicsPen = object
GraphicsRenderer = object
GridBagSizer = object
GridSizer = object
HDR_SORT_ICON_DOWN = object
HDR_SORT_ICON_NONE = object
HDR_SORT_ICON_UP = object
HD_ALLOW_HIDE = 0
HD_ALLOW_REORDER = 0
HD_DEFAULT_STYLE = 0
HELP = 0
HELP_NETSCAPE = 0
HELP_SEARCH_ALL = object
HELP_SEARCH_INDEX = object
HORIZONTAL = object
HORIZONTAL_HATCH = 0
HOURGLASS_CURSOR = object
HSCROLL = 0
HScrolledWindow = object
HTMLDataObject = object
HT_MAX = object
HT_NOWHERE = object
HT_SCROLLBAR_ARROW_LINE_1 = object
HT_SCROLLBAR_ARROW_LINE_2 = object
HT_SCROLLBAR_ARROW_PAGE_1 = object
HT_SCROLLBAR_ARROW_PAGE_2 = object
HT_SCROLLBAR_BAR_1 = object
HT_SCROLLBAR_BAR_2 = object
HT_SCROLLBAR_FIRST = object
HT_SCROLLBAR_LAST = object
HT_SCROLLBAR_THUMB = object
HT_WINDOW_CORNER = object
HT_WINDOW_HORZ_SCROLLBAR = object
HT_WINDOW_INSIDE = object
HT_WINDOW_OUTSIDE = object
HT_WINDOW_VERT_SCROLLBAR = object
HVScrolledWindow = object
HandleFatalExceptions = dummy_function
HeaderButtonParams = object
HeaderColumn = object
HeaderColumnSimple = object
HeaderCtrl = object
HeaderCtrlEvent = object
HeaderCtrlNameStr = bytes()
HeaderCtrlSimple = object
HeaderSortIconType = object
Height = object
HelpControllerBase = object
HelpControllerHelpProvider = object
HelpEvent = object
HelpProvider = object
HelpSearchMode = object
HitTest = object
ICONIZE = 0
ICON_ASTERISK = 0
ICON_AUTH_NEEDED = 0
ICON_ERROR = 0
ICON_EXCLAMATION = 0
ICON_HAND = 0
ICON_INFORMATION = 0
ICON_MASK = 0
ICON_NONE = 0
ICON_QUESTION = 0
ICON_SCREEN_DEPTH = 0
ICON_STOP = 0
ICON_WARNING = 0
IDLE_PROCESS_ALL = object
IDLE_PROCESS_SPECIFIED = object
ID_ABORT = object
ID_ABOUT = object
ID_ADD = object
ID_ANY = object
ID_APPLY = object
ID_AUTO_HIGHEST = object
ID_AUTO_LOWEST = object
ID_BACKWARD = object
ID_BOLD = object
ID_BOTTOM = object
ID_CANCEL = object
ID_CDROM = object
ID_CLEAR = object
ID_CLOSE = object
ID_CLOSE_ALL = object
ID_CLOSE_FRAME = object
ID_CONTEXT_HELP = object
ID_CONVERT = object
ID_COPY = object
ID_CUT = object
ID_DEFAULT = object
ID_DELETE = object
ID_DOWN = object
ID_DUPLICATE = object
ID_EDIT = object
ID_EXECUTE = object
ID_EXIT = object
ID_FILE = object
ID_FILE1 = object
ID_FILE2 = object
ID_FILE3 = object
ID_FILE4 = object
ID_FILE5 = object
ID_FILE6 = object
ID_FILE7 = object
ID_FILE8 = object
ID_FILE9 = object
ID_FILECTRL = object
ID_FILEDLGG = object
ID_FIND = object
ID_FIRST = object
ID_FLOPPY = object
ID_FORWARD = object
ID_HARDDISK = object
ID_HELP = object
ID_HELP_COMMANDS = object
ID_HELP_CONTENTS = object
ID_HELP_CONTEXT = object
ID_HELP_INDEX = object
ID_HELP_PROCEDURES = object
ID_HELP_SEARCH = object
ID_HIGHEST = object
ID_HOME = object
ID_ICONIZE_FRAME = object
ID_IGNORE = object
ID_INDENT = object
ID_INDEX = object
ID_INFO = object
ID_ITALIC = object
ID_JUMP_TO = object
ID_JUSTIFY_CENTER = object
ID_JUSTIFY_FILL = object
ID_JUSTIFY_LEFT = object
ID_JUSTIFY_RIGHT = object
ID_LAST = object
ID_LOWEST = object
ID_MAXIMIZE_FRAME = object
ID_MDI_WINDOW_ARRANGE_ICONS = object
ID_MDI_WINDOW_CASCADE = object
ID_MDI_WINDOW_FIRST = object
ID_MDI_WINDOW_LAST = object
ID_MDI_WINDOW_NEXT = object
ID_MDI_WINDOW_PREV = object
ID_MDI_WINDOW_TILE_HORZ = object
ID_MDI_WINDOW_TILE_VERT = object
ID_MORE = object
ID_MOVE_FRAME = object
ID_NETWORK = object
ID_NEW = object
ID_NO = object
ID_NONE = object
ID_NOTOALL = object
ID_OK = object
ID_OPEN = object
ID_PAGE_SETUP = object
ID_PASTE = object
ID_PREFERENCES = object
ID_PREVIEW = object
ID_PREVIEW_CLOSE = 0
ID_PREVIEW_FIRST = 0
ID_PREVIEW_GOTO = 0
ID_PREVIEW_LAST = 0
ID_PREVIEW_NEXT = 0
ID_PREVIEW_PREVIOUS = 0
ID_PREVIEW_PRINT = 0
ID_PREVIEW_ZOOM = 0
ID_PREVIEW_ZOOM_IN = 0
ID_PREVIEW_ZOOM_OUT = 0
ID_PRINT = object
ID_PRINT_SETUP = object
ID_PROPERTIES = object
ID_REDO = object
ID_REFRESH = object
ID_REMOVE = object
ID_REPLACE = object
ID_REPLACE_ALL = object
ID_RESET = object
ID_RESIZE_FRAME = object
ID_RESTORE_FRAME = object
ID_RETRY = object
ID_REVERT = object
ID_REVERT_TO_SAVED = object
ID_SAVE = object
ID_SAVEAS = object
ID_SELECTALL = object
ID_SELECT_COLOR = object
ID_SELECT_FONT = object
ID_SEPARATOR = object
ID_SETUP = object
ID_SORT_ASCENDING = object
ID_SORT_DESCENDING = object
ID_SPELL_CHECK = object
ID_STATIC = object
ID_STOP = object
ID_STRIKETHROUGH = object
ID_SYSTEM_MENU = object
ID_TOP = object
ID_UNDELETE = object
ID_UNDERLINE = object
ID_UNDO = object
ID_UNINDENT = object
ID_UP = object
ID_VIEW_DETAILS = object
ID_VIEW_LARGEICONS = object
ID_VIEW_LIST = object
ID_VIEW_SMALLICONS = object
ID_VIEW_SORTDATE = object
ID_VIEW_SORTNAME = object
ID_VIEW_SORTSIZE = object
ID_VIEW_SORTTYPE = object
ID_YES = object
ID_YESTOALL = object
ID_ZOOM_100 = object
ID_ZOOM_FIT = object
ID_ZOOM_IN = object
ID_ZOOM_OUT = object
IFFHandler = object
IMAGELIST_DRAW_FOCUSED = 0
IMAGELIST_DRAW_NORMAL = 0
IMAGELIST_DRAW_SELECTED = 0
IMAGELIST_DRAW_TRANSPARENT = 0
IMAGE_ALPHA_OPAQUE = 0
IMAGE_ALPHA_THRESHOLD = 0
IMAGE_ALPHA_TRANSPARENT = 0
IMAGE_LIST_NORMAL = 0
IMAGE_LIST_SMALL = 0
IMAGE_LIST_STATE = 0
IMAGE_OPTION_BMP_FORMAT = 'wxBMP_FORMAT'
IMAGE_OPTION_CUR_HOTSPOT_X = 'HotSpotX'
IMAGE_OPTION_CUR_HOTSPOT_Y = 'HotSpotY'
IMAGE_OPTION_FILENAME = 'FileName'
IMAGE_OPTION_GIF_COMMENT = 'GifComment'
IMAGE_OPTION_MAX_HEIGHT = 'MaxHeight'
IMAGE_OPTION_MAX_WIDTH = 'MaxWidth'
IMAGE_OPTION_ORIGINAL_HEIGHT = 'OriginalHeight'
IMAGE_OPTION_ORIGINAL_WIDTH = 'OriginalWidth'
IMAGE_OPTION_PNG_BITDEPTH = 'PngBitDepth'
IMAGE_OPTION_PNG_COMPRESSION_BUFFER_SIZE = 'PngZB'
IMAGE_OPTION_PNG_COMPRESSION_LEVEL = 'PngZL'
IMAGE_OPTION_PNG_COMPRESSION_MEM_LEVEL = 'PngZM'
IMAGE_OPTION_PNG_COMPRESSION_STRATEGY = 'PngZS'
IMAGE_OPTION_PNG_FILTER = 'PngF'
IMAGE_OPTION_PNG_FORMAT = 'PngFormat'
IMAGE_OPTION_QUALITY = 'quality'
IMAGE_OPTION_RESOLUTION = 'Resolution'
IMAGE_OPTION_RESOLUTIONUNIT = 'ResolutionUnit'
IMAGE_OPTION_RESOLUTIONX = 'ResolutionX'
IMAGE_OPTION_RESOLUTIONY = 'ResolutionY'
IMAGE_OPTION_TIFF_BITSPERSAMPLE = 'BitsPerSample'
IMAGE_OPTION_TIFF_COMPRESSION = 'Compression'
IMAGE_OPTION_TIFF_IMAGEDESCRIPTOR = 'ImageDescriptor'
IMAGE_OPTION_TIFF_PHOTOMETRIC = 'Photometric'
IMAGE_OPTION_TIFF_SAMPLESPERPIXEL = 'SamplesPerPixel'
IMAGE_QUALITY_BICUBIC = object
IMAGE_QUALITY_BILINEAR = object
IMAGE_QUALITY_BOX_AVERAGE = object
IMAGE_QUALITY_HIGH = object
IMAGE_QUALITY_NEAREST = object
IMAGE_QUALITY_NORMAL = object
IMAGE_RESOLUTION_CM = object
IMAGE_RESOLUTION_INCHES = object
IMAGE_RESOLUTION_NONE = object
INT16_MAX = 0
INT16_MIN = 0
INT32_MAX = 0
INT32_MIN = 0
INT64_MAX = 0
INT64_MIN = 0
INT8_MAX = 0
INT8_MIN = 0
INTERPOLATION_BEST = object
INTERPOLATION_DEFAULT = object
INTERPOLATION_FAST = object
INTERPOLATION_GOOD = object
INTERPOLATION_NONE = object
INVERT = object
ITALIC = 0
ITALIC_FONT = object
ITEM_CHECK = object
ITEM_DROPDOWN = object
ITEM_MAX = object
ITEM_NORMAL = object
ITEM_RADIO = object
ITEM_SEPARATOR = object
Icon = object
IconBundle = object
IconLocation = object
IconizeEvent = object
IdManager = object
IdleEvent = object
IdleMode = object
Image = object
ImageArray = object
ImageFromBitmap = dummy_function
ImageFromBuffer = dummy_function
ImageFromData = dummy_function
ImageFromDataWithAlpha = dummy_function
ImageFromStream = dummy_function
ImageHandler = object
ImageHistogram = object
ImageList = object
ImagePNGType = object
ImageResizeQuality = object
ImageResolution = object
InRegion = object
IndividualLayoutConstraint = object
InfoBar = object
InfoMessageBox = dummy_function
InitAllImageHandlers = dummy_function
InitDialogEvent = object
InputStream = object
Inside = object
IntCArrayHolder = object
InternetFSHandler = object
InterpolationQuality = object
IntersectRect = dummy_function
InvalidDateTime = object
IsBusy = dummy_function
IsDragResultOk = dummy_function
IsMainThread = dummy_function
IsPlatform64Bit = dummy_function
IsPlatformLittleEndian = dummy_function
ItemContainer = object
ItemContainerImmutable = object
ItemKind = object
JOIN_BEVEL = object
JOIN_INVALID = object
JOIN_MITER = object
JOIN_ROUND = object
JOYSTICK1 = 0
JOYSTICK2 = 0
JOY_BUTTON1 = 0
JOY_BUTTON2 = 0
JOY_BUTTON3 = 0
JOY_BUTTON4 = 0
JOY_BUTTON_ANY = 0
JPEGHandler = object
JoystickEvent = object
KILL_ACCESS_DENIED = object
KILL_BAD_SIGNAL = object
KILL_CHILDREN = object
KILL_ERROR = object
KILL_NOCHILDREN = object
KILL_NO_PROCESS = object
KILL_OK = object
KeyCategoryFlags = object
KeyCode = object
KeyEvent = object
KeyModifier = object
KeyboardState = object
Kill = dummy_function
KillError = object
KillFlags = object
LANDSCAPE = object
LANGUAGE_ABKHAZIAN = object
LANGUAGE_AFAR = object
LANGUAGE_AFRIKAANS = object
LANGUAGE_ALBANIAN = object
LANGUAGE_AMHARIC = object
LANGUAGE_ARABIC = object
LANGUAGE_ARABIC_ALGERIA = object
LANGUAGE_ARABIC_BAHRAIN = object
LANGUAGE_ARABIC_EGYPT = object
LANGUAGE_ARABIC_IRAQ = object
LANGUAGE_ARABIC_JORDAN = object
LANGUAGE_ARABIC_KUWAIT = object
LANGUAGE_ARABIC_LEBANON = object
LANGUAGE_ARABIC_LIBYA = object
LANGUAGE_ARABIC_MOROCCO = object
LANGUAGE_ARABIC_OMAN = object
LANGUAGE_ARABIC_QATAR = object
LANGUAGE_ARABIC_SAUDI_ARABIA = object
LANGUAGE_ARABIC_SUDAN = object
LANGUAGE_ARABIC_SYRIA = object
LANGUAGE_ARABIC_TUNISIA = object
LANGUAGE_ARABIC_UAE = object
LANGUAGE_ARABIC_YEMEN = object
LANGUAGE_ARMENIAN = object
LANGUAGE_ASSAMESE = object
LANGUAGE_ASTURIAN = object
LANGUAGE_AYMARA = object
LANGUAGE_AZERI = object
LANGUAGE_AZERI_CYRILLIC = object
LANGUAGE_AZERI_LATIN = object
LANGUAGE_BASHKIR = object
LANGUAGE_BASQUE = object
LANGUAGE_BELARUSIAN = object
LANGUAGE_BENGALI = object
LANGUAGE_BHUTANI = object
LANGUAGE_BIHARI = object
LANGUAGE_BISLAMA = object
LANGUAGE_BOSNIAN = object
LANGUAGE_BRETON = object
LANGUAGE_BULGARIAN = object
LANGUAGE_BURMESE = object
LANGUAGE_CAMBODIAN = object
LANGUAGE_CATALAN = object
LANGUAGE_CHINESE = object
LANGUAGE_CHINESE_HONGKONG = object
LANGUAGE_CHINESE_MACAU = object
LANGUAGE_CHINESE_SIMPLIFIED = object
LANGUAGE_CHINESE_SINGAPORE = object
LANGUAGE_CHINESE_TAIWAN = object
LANGUAGE_CHINESE_TRADITIONAL = object
LANGUAGE_CORSICAN = object
LANGUAGE_CROATIAN = object
LANGUAGE_CZECH = object
LANGUAGE_DANISH = object
LANGUAGE_DEFAULT = object
LANGUAGE_DUTCH = object
LANGUAGE_DUTCH_BELGIAN = object
LANGUAGE_ENGLISH = object
LANGUAGE_ENGLISH_AUSTRALIA = object
LANGUAGE_ENGLISH_BELIZE = object
LANGUAGE_ENGLISH_BOTSWANA = object
LANGUAGE_ENGLISH_CANADA = object
LANGUAGE_ENGLISH_CARIBBEAN = object
LANGUAGE_ENGLISH_DENMARK = object
LANGUAGE_ENGLISH_EIRE = object
LANGUAGE_ENGLISH_JAMAICA = object
LANGUAGE_ENGLISH_NEW_ZEALAND = object
LANGUAGE_ENGLISH_PHILIPPINES = object
LANGUAGE_ENGLISH_SOUTH_AFRICA = object
LANGUAGE_ENGLISH_TRINIDAD = object
LANGUAGE_ENGLISH_UK = object
LANGUAGE_ENGLISH_US = object
LANGUAGE_ENGLISH_ZIMBABWE = object
LANGUAGE_ESPERANTO = object
LANGUAGE_ESTONIAN = object
LANGUAGE_FAEROESE = object
LANGUAGE_FARSI = object
LANGUAGE_FIJI = object
LANGUAGE_FINNISH = object
LANGUAGE_FRENCH = object
LANGUAGE_FRENCH_BELGIAN = object
LANGUAGE_FRENCH_CANADIAN = object
LANGUAGE_FRENCH_LUXEMBOURG = object
LANGUAGE_FRENCH_MONACO = object
LANGUAGE_FRENCH_SWISS = object
LANGUAGE_FRISIAN = object
LANGUAGE_GALICIAN = object
LANGUAGE_GEORGIAN = object
LANGUAGE_GERMAN = object
LANGUAGE_GERMAN_AUSTRIAN = object
LANGUAGE_GERMAN_BELGIUM = object
LANGUAGE_GERMAN_LIECHTENSTEIN = object
LANGUAGE_GERMAN_LUXEMBOURG = object
LANGUAGE_GERMAN_SWISS = object
LANGUAGE_GREEK = object
LANGUAGE_GREENLANDIC = object
LANGUAGE_GUARANI = object
LANGUAGE_GUJARATI = object
LANGUAGE_HAUSA = object
LANGUAGE_HEBREW = object
LANGUAGE_HINDI = object
LANGUAGE_HUNGARIAN = object
LANGUAGE_ICELANDIC = object
LANGUAGE_INDONESIAN = object
LANGUAGE_INTERLINGUA = object
LANGUAGE_INTERLINGUE = object
LANGUAGE_INUKTITUT = object
LANGUAGE_INUPIAK = object
LANGUAGE_IRISH = object
LANGUAGE_ITALIAN = object
LANGUAGE_ITALIAN_SWISS = object
LANGUAGE_JAPANESE = object
LANGUAGE_JAVANESE = object
LANGUAGE_KABYLE = object
LANGUAGE_KANNADA = object
LANGUAGE_KASHMIRI = object
LANGUAGE_KASHMIRI_INDIA = object
LANGUAGE_KAZAKH = object
LANGUAGE_KERNEWEK = object
LANGUAGE_KINYARWANDA = object
LANGUAGE_KIRGHIZ = object
LANGUAGE_KIRUNDI = object
LANGUAGE_KONKANI = object
LANGUAGE_KOREAN = object
LANGUAGE_KURDISH = object
LANGUAGE_LAOTHIAN = object
LANGUAGE_LATIN = object
LANGUAGE_LATVIAN = object
LANGUAGE_LINGALA = object
LANGUAGE_LITHUANIAN = object
LANGUAGE_MACEDONIAN = object
LANGUAGE_MALAGASY = object
LANGUAGE_MALAY = object
LANGUAGE_MALAYALAM = object
LANGUAGE_MALAY_BRUNEI_DARUSSALAM = object
LANGUAGE_MALAY_MALAYSIA = object
LANGUAGE_MALTESE = object
LANGUAGE_MANIPURI = object
LANGUAGE_MAORI = object
LANGUAGE_MARATHI = object
LANGUAGE_MOLDAVIAN = object
LANGUAGE_MONGOLIAN = object
LANGUAGE_NAURU = object
LANGUAGE_NEPALI = object
LANGUAGE_NEPALI_INDIA = object
LANGUAGE_NORWEGIAN_BOKMAL = object
LANGUAGE_NORWEGIAN_NYNORSK = object
LANGUAGE_OCCITAN = object
LANGUAGE_ORIYA = object
LANGUAGE_OROMO = object
LANGUAGE_PASHTO = object
LANGUAGE_POLISH = object
LANGUAGE_PORTUGUESE = object
LANGUAGE_PORTUGUESE_BRAZILIAN = object
LANGUAGE_PUNJABI = object
LANGUAGE_QUECHUA = object
LANGUAGE_RHAETO_ROMANCE = object
LANGUAGE_ROMANIAN = object
LANGUAGE_RUSSIAN = object
LANGUAGE_RUSSIAN_UKRAINE = object
LANGUAGE_SAMI = object
LANGUAGE_SAMOAN = object
LANGUAGE_SANGHO = object
LANGUAGE_SANSKRIT = object
LANGUAGE_SCOTS_GAELIC = object
LANGUAGE_SERBIAN = object
LANGUAGE_SERBIAN_CYRILLIC = object
LANGUAGE_SERBIAN_LATIN = object
LANGUAGE_SERBO_CROATIAN = object
LANGUAGE_SESOTHO = object
LANGUAGE_SETSWANA = object
LANGUAGE_SHONA = object
LANGUAGE_SINDHI = object
LANGUAGE_SINHALESE = object
LANGUAGE_SISWATI = object
LANGUAGE_SLOVAK = object
LANGUAGE_SLOVENIAN = object
LANGUAGE_SOMALI = object
LANGUAGE_SPANISH = object
LANGUAGE_SPANISH_ARGENTINA = object
LANGUAGE_SPANISH_BOLIVIA = object
LANGUAGE_SPANISH_CHILE = object
LANGUAGE_SPANISH_COLOMBIA = object
LANGUAGE_SPANISH_COSTA_RICA = object
LANGUAGE_SPANISH_DOMINICAN_REPUBLIC = object
LANGUAGE_SPANISH_ECUADOR = object
LANGUAGE_SPANISH_EL_SALVADOR = object
LANGUAGE_SPANISH_GUATEMALA = object
LANGUAGE_SPANISH_HONDURAS = object
LANGUAGE_SPANISH_MEXICAN = object
LANGUAGE_SPANISH_MODERN = object
LANGUAGE_SPANISH_NICARAGUA = object
LANGUAGE_SPANISH_PANAMA = object
LANGUAGE_SPANISH_PARAGUAY = object
LANGUAGE_SPANISH_PERU = object
LANGUAGE_SPANISH_PUERTO_RICO = object
LANGUAGE_SPANISH_URUGUAY = object
LANGUAGE_SPANISH_US = object
LANGUAGE_SPANISH_VENEZUELA = object
LANGUAGE_SUNDANESE = object
LANGUAGE_SWAHILI = object
LANGUAGE_SWEDISH = object
LANGUAGE_SWEDISH_FINLAND = object
LANGUAGE_TAGALOG = object
LANGUAGE_TAJIK = object
LANGUAGE_TAMIL = object
LANGUAGE_TATAR = object
LANGUAGE_TELUGU = object
LANGUAGE_THAI = object
LANGUAGE_TIBETAN = object
LANGUAGE_TIGRINYA = object
LANGUAGE_TONGA = object
LANGUAGE_TSONGA = object
LANGUAGE_TURKISH = object
LANGUAGE_TURKMEN = object
LANGUAGE_TWI = object
LANGUAGE_UIGHUR = object
LANGUAGE_UKRAINIAN = object
LANGUAGE_UNKNOWN = object
LANGUAGE_URDU = object
LANGUAGE_URDU_INDIA = object
LANGUAGE_URDU_PAKISTAN = object
LANGUAGE_USER_DEFINED = object
LANGUAGE_UZBEK = object
LANGUAGE_UZBEK_CYRILLIC = object
LANGUAGE_UZBEK_LATIN = object
LANGUAGE_VALENCIAN = object
LANGUAGE_VIETNAMESE = object
LANGUAGE_VOLAPUK = object
LANGUAGE_WELSH = object
LANGUAGE_WOLOF = object
LANGUAGE_XHOSA = object
LANGUAGE_YIDDISH = object
LANGUAGE_YORUBA = object
LANGUAGE_ZHUANG = object
LANGUAGE_ZULU = object
LAYOUT_DEFAULT_MARGIN = 0
LB_ALIGN_MASK = 0
LB_ALWAYS_SB = 0
LB_BOTTOM = 0
LB_DEFAULT = 0
LB_EXTENDED = 0
LB_HSCROLL = 0
LB_INT_HEIGHT = 0
LB_LEFT = 0
LB_MULTIPLE = 0
LB_NEEDED_SB = 0
LB_NO_SB = 0
LB_OWNERDRAW = 0
LB_RIGHT = 0
LB_SINGLE = 0
LB_SORT = 0
LB_TOP = 0
LC_ALIGN_LEFT = 0
LC_ALIGN_TOP = 0
LC_AUTOARRANGE = 0
LC_EDIT_LABELS = 0
LC_HRULES = 0
LC_ICON = 0
LC_LIST = 0
LC_MASK_ALIGN = 0
LC_MASK_SORT = 0
LC_MASK_TYPE = 0
LC_NO_HEADER = 0
LC_NO_SORT_HEADER = 0
LC_REPORT = 0
LC_SINGLE_SEL = 0
LC_SMALL_ICON = 0
LC_SORT_ASCENDING = 0
LC_SORT_DESCENDING = 0
LC_VIRTUAL = 0
LC_VRULES = 0
LEFT = object
LIGHT = 0
LIGHT_GREY = object
LIGHT_GREY_BRUSH = object
LIGHT_GREY_PEN = object
LIST_ALIGN_DEFAULT = 0
LIST_ALIGN_LEFT = 0
LIST_ALIGN_SNAP_TO_GRID = 0
LIST_ALIGN_TOP = 0
LIST_AUTOSIZE = 0
LIST_AUTOSIZE_USEHEADER = 0
LIST_FIND_DOWN = 0
LIST_FIND_LEFT = 0
LIST_FIND_RIGHT = 0
LIST_FIND_UP = 0
LIST_FORMAT_CENTER = object
LIST_FORMAT_CENTRE = object
LIST_FORMAT_LEFT = object
LIST_FORMAT_RIGHT = object
LIST_GETSUBITEMRECT_WHOLEITEM = 0
LIST_HITTEST_ABOVE = 0
LIST_HITTEST_BELOW = 0
LIST_HITTEST_NOWHERE = 0
LIST_HITTEST_ONITEM = 0
LIST_HITTEST_ONITEMICON = 0
LIST_HITTEST_ONITEMLABEL = 0
LIST_HITTEST_ONITEMRIGHT = 0
LIST_HITTEST_ONITEMSTATEICON = 0
LIST_HITTEST_TOLEFT = 0
LIST_HITTEST_TORIGHT = 0
LIST_MASK_DATA = 0
LIST_MASK_FORMAT = 0
LIST_MASK_IMAGE = 0
LIST_MASK_STATE = 0
LIST_MASK_TEXT = 0
LIST_MASK_WIDTH = 0
LIST_NEXT_ABOVE = 0
LIST_NEXT_ALL = 0
LIST_NEXT_BELOW = 0
LIST_NEXT_LEFT = 0
LIST_NEXT_RIGHT = 0
LIST_RECT_BOUNDS = 0
LIST_RECT_ICON = 0
LIST_RECT_LABEL = 0
LIST_SET_ITEM = 0
LIST_STATE_CUT = 0
LIST_STATE_DISABLED = 0
LIST_STATE_DONTCARE = 0
LIST_STATE_DROPHILITED = 0
LIST_STATE_FILTERED = 0
LIST_STATE_FOCUSED = 0
LIST_STATE_INUSE = 0
LIST_STATE_PICKED = 0
LIST_STATE_SELECTED = 0
LIST_STATE_SOURCE = 0
LI_HORIZONTAL = 0
LI_VERTICAL = 0
LOCALE_CAT_DATE = object
LOCALE_CAT_DEFAULT = object
LOCALE_CAT_MONEY = object
LOCALE_CAT_NUMBER = object
LOCALE_DATE_TIME_FMT = object
LOCALE_DECIMAL_POINT = object
LOCALE_DONT_LOAD_DEFAULT = object
LOCALE_LOAD_DEFAULT = object
LOCALE_LONG_DATE_FMT = object
LOCALE_SHORT_DATE_FMT = object
LOCALE_THOUSANDS_SEP = object
LOCALE_TIME_FMT = object
LOG_Debug = object
LOG_Error = object
LOG_FatalError = object
LOG_Info = object
LOG_Max = object
LOG_Message = object
LOG_Progress = object
LOG_Status = object
LOG_Trace = object
LOG_User = object
LOG_Warning = object
LONG_DASH = 0
Language = object
LanguageInfo = object
LaunchDefaultApplication = dummy_function
LaunchDefaultBrowser = dummy_function
LayoutConstraints = object
LayoutDirection = object
Layout_Default = object
Layout_LeftToRight = object
Layout_RightToLeft = object
Left = object
LeftOf = object
LinuxDistributionInfo = object
ListBox = object
ListBoxNameStr = bytes()
ListColumnFormat = object
ListCtrl = object
ListCtrlNameStr = bytes()
ListEvent = object
ListItem = object
ListItemAttr = object
ListView = object
Listbook = object
LoadFileSelector = dummy_function
Locale = object
LocaleCategory = object
LocaleInfo = object
LocaleInitFlags = object
Log = object
LogBuffer = object
LogChain = object
LogDebug = dummy_function
LogError = dummy_function
LogFatalError = dummy_function
LogFormatter = object
LogGeneric = dummy_function
LogGui = object
LogInterposer = object
LogInterposerTemp = object
LogLevelValues = object
LogMessage = dummy_function
LogNull = object
LogRecordInfo = object
LogStatus = dummy_function
LogStderr = object
LogSysError = dummy_function
LogTextCtrl = object
LogVerbose = dummy_function
LogWarning = dummy_function
LogWindow = object
MAJOR_VERSION = 0
MAXIMIZE = 0
MAXIMIZE_BOX = 0
MB_DOCKABLE = 0
MDIChildFrame = object
MDIClientWindow = object
MDIParentFrame = object
MEDIUM_GREY_BRUSH = object
MEDIUM_GREY_PEN = object
MENU_TEAROFF = 0
MINIMIZE = 0
MINIMIZE_BOX = 0
MINOR_VERSION = 0
MM_LOMETRIC = object
MM_METRIC = object
MM_POINTS = object
MM_TEXT = object
MM_TWIPS = object
MODERN = 0
MOD_ALL = object
MOD_ALT = object
MOD_ALTGR = object
MOD_CMD = object
MOD_CONTROL = object
MOD_META = object
MOD_NONE = object
MOD_RAW_CONTROL = object
MOD_SHIFT = object
MOD_WIN = object
MORE = 0
MOUSE_BTN_ANY = object
MOUSE_BTN_AUX1 = object
MOUSE_BTN_AUX2 = object
MOUSE_BTN_LEFT = object
MOUSE_BTN_MAX = object
MOUSE_BTN_MIDDLE = object
MOUSE_BTN_NONE = object
MOUSE_BTN_RIGHT = object
MOUSE_WHEEL_HORIZONTAL = object
MOUSE_WHEEL_VERTICAL = object
MacThemeColour = dummy_function
MappingMode = object
Mask = object
Matrix2D = object
MaximizeEvent = object
MemoryDC = object
MemoryFSHandler = object
Menu = object
MenuBar = object
MenuEvent = object
MenuItem = object
MenuItemList = object
MenuItemList_iterator = object
MenuList = object
MenuList_iterator = object
MessageBox = dummy_function
MessageBoxCaptionStr = bytes()
MessageDialog = object
Metafile = object
MetafileDC = object
MicroSleep = dummy_function
MilliSleep = dummy_function
MimeTypesManager = object
MiniFrame = object
MirrorDC = object
ModalDialogHook = object
MouseButton = object
MouseCaptureChangedEvent = object
MouseCaptureLostEvent = object
MouseEvent = object
MouseEventsManager = object
MouseState = object
MouseWheelAxis = object
MoveEvent = object
MsgCatalog = object
MultiChoiceDialog = object
NAND = object
NAVDIR_DOWN = object
NAVDIR_FIRSTCHILD = object
NAVDIR_LASTCHILD = object
NAVDIR_LEFT = object
NAVDIR_NEXT = object
NAVDIR_PREVIOUS = object
NAVDIR_RIGHT = object
NAVDIR_UP = object
NB_BOTTOM = 0
NB_DEFAULT = 0
NB_FIXEDWIDTH = 0
NB_FLAT = 0
NB_HITTEST_NOWHERE = 0
NB_HITTEST_ONICON = 0
NB_HITTEST_ONITEM = 0
NB_HITTEST_ONLABEL = 0
NB_HITTEST_ONPAGE = 0
NB_LEFT = 0
NB_MULTILINE = 0
NB_NOPAGETHEME = 0
NB_RIGHT = 0
NB_TOP = 0
NO = 0
NOR = object
NORMAL = 0
NORMAL_FONT = object
NORTH = object
NOT_FOUND = 0
NO_BORDER = 0
NO_DEFAULT = 0
NO_FULL_REPAINT_ON_RESIZE = 0
NO_IMAGE = 0
NO_OP = object
NamedColour = object
NativeFontInfo = object
NativePixelData = object
NativePixelData_Accessor = object
NavDir = object
NavigationKeyEvent = object
NewEventType = dummy_function
NewId = dummy_function
NewIdRef = dummy_function
NonOwnedWindow = object
Notebook = object
NotebookNameStr = bytes()
NotifyEvent = object
Now = dummy_function
NullAcceleratorTable = object
NullBitmap = object
NullBrush = object
NullColour = object
NullCursor = object
NullFont = object
NullGraphicsBitmap = object
NullGraphicsBrush = object
NullGraphicsFont = object
NullGraphicsMatrix = object
NullGraphicsPath = object
NullGraphicsPen = object
NullIcon = object
NullIconBundle = object
NullImage = object
NullPalette = object
NullPen = object
NumberEntryDialog = object
OBJID_ALERT = object
OBJID_CARET = object
OBJID_CLIENT = object
OBJID_CURSOR = object
OBJID_HSCROLL = object
OBJID_MENU = object
OBJID_SIZEGRIP = object
OBJID_SOUND = object
OBJID_SYSMENU = object
OBJID_TITLEBAR = object
OBJID_VSCROLL = object
OBJID_WINDOW = object
ODDEVEN_RULE = object
OK = 0
OK_DEFAULT = 0
OR = object
ORIENTATION_MASK = object
OR_INVERT = object
OR_REVERSE = object
OS_DOS = object
OS_MAC = object
OS_MAC_OS = object
OS_MAC_OSX_DARWIN = object
OS_OS2 = object
OS_UNIX = object
OS_UNIX_AIX = object
OS_UNIX_FREEBSD = object
OS_UNIX_HPUX = object
OS_UNIX_LINUX = object
OS_UNIX_NETBSD = object
OS_UNIX_OPENBSD = object
OS_UNIX_SOLARIS = object
OS_UNKNOWN = object
OS_WINDOWS = object
OS_WINDOWS_9X = object
OS_WINDOWS_CE = object
OS_WINDOWS_MICRO = object
OS_WINDOWS_NT = object
Object = object
OperatingSystemId = object
Orientation = object
OutBottom = object
OutCode = object
OutLeft = object
OutRegion = object
OutRight = object
OutTop = object
OutputStream = object
Overlay = object
PAPER_10X11 = object
PAPER_10X14 = object
PAPER_11X17 = object
PAPER_12X11 = object
PAPER_15X11 = object
PAPER_9X11 = object
PAPER_A2 = object
PAPER_A3 = object
PAPER_A3_EXTRA = object
PAPER_A3_EXTRA_TRANSVERSE = object
PAPER_A3_ROTATED = object
PAPER_A3_TRANSVERSE = object
PAPER_A4 = object
PAPER_A4SMALL = object
PAPER_A4_EXTRA = object
PAPER_A4_PLUS = object
PAPER_A4_ROTATED = object
PAPER_A4_TRANSVERSE = object
PAPER_A5 = object
PAPER_A5_EXTRA = object
PAPER_A5_ROTATED = object
PAPER_A5_TRANSVERSE = object
PAPER_A6 = object
PAPER_A6_ROTATED = object
PAPER_A_PLUS = object
PAPER_B4 = object
PAPER_B4_JIS_ROTATED = object
PAPER_B5 = object
PAPER_B5_EXTRA = object
PAPER_B5_JIS_ROTATED = object
PAPER_B5_TRANSVERSE = object
PAPER_B6_JIS = object
PAPER_B6_JIS_ROTATED = object
PAPER_B_PLUS = object
PAPER_CSHEET = object
PAPER_DBL_JAPANESE_POSTCARD = object
PAPER_DBL_JAPANESE_POSTCARD_ROTATED = object
PAPER_DSHEET = object
PAPER_ENV_10 = object
PAPER_ENV_11 = object
PAPER_ENV_12 = object
PAPER_ENV_14 = object
PAPER_ENV_9 = object
PAPER_ENV_B4 = object
PAPER_ENV_B5 = object
PAPER_ENV_B6 = object
PAPER_ENV_C3 = object
PAPER_ENV_C4 = object
PAPER_ENV_C5 = object
PAPER_ENV_C6 = object
PAPER_ENV_C65 = object
PAPER_ENV_DL = object
PAPER_ENV_INVITE = object
PAPER_ENV_ITALY = object
PAPER_ENV_MONARCH = object
PAPER_ENV_PERSONAL = object
PAPER_ESHEET = object
PAPER_EXECUTIVE = object
PAPER_FANFOLD_LGL_GERMAN = object
PAPER_FANFOLD_STD_GERMAN = object
PAPER_FANFOLD_US = object
PAPER_FOLIO = object
PAPER_ISO_B4 = object
PAPER_JAPANESE_POSTCARD = object
PAPER_JAPANESE_POSTCARD_ROTATED = object
PAPER_JENV_CHOU3 = object
PAPER_JENV_CHOU3_ROTATED = object
PAPER_JENV_CHOU4 = object
PAPER_JENV_CHOU4_ROTATED = object
PAPER_JENV_KAKU2 = object
PAPER_JENV_KAKU2_ROTATED = object
PAPER_JENV_KAKU3 = object
PAPER_JENV_KAKU3_ROTATED = object
PAPER_JENV_YOU4 = object
PAPER_JENV_YOU4_ROTATED = object
PAPER_LEDGER = object
PAPER_LEGAL = object
PAPER_LEGAL_EXTRA = object
PAPER_LETTER = object
PAPER_LETTERSMALL = object
PAPER_LETTER_EXTRA = object
PAPER_LETTER_EXTRA_TRANSVERSE = object
PAPER_LETTER_PLUS = object
PAPER_LETTER_ROTATED = object
PAPER_LETTER_TRANSVERSE = object
PAPER_NONE = object
PAPER_NOTE = object
PAPER_P16K = object
PAPER_P16K_ROTATED = object
PAPER_P32K = object
PAPER_P32KBIG = object
PAPER_P32KBIG_ROTATED = object
PAPER_P32K_ROTATED = object
PAPER_PENV_1 = object
PAPER_PENV_10 = object
PAPER_PENV_10_ROTATED = object
PAPER_PENV_1_ROTATED = object
PAPER_PENV_2 = object
PAPER_PENV_2_ROTATED = object
PAPER_PENV_3 = object
PAPER_PENV_3_ROTATED = object
PAPER_PENV_4 = object
PAPER_PENV_4_ROTATED = object
PAPER_PENV_5 = object
PAPER_PENV_5_ROTATED = object
PAPER_PENV_6 = object
PAPER_PENV_6_ROTATED = object
PAPER_PENV_7 = object
PAPER_PENV_7_ROTATED = object
PAPER_PENV_8 = object
PAPER_PENV_8_ROTATED = object
PAPER_PENV_9 = object
PAPER_PENV_9_ROTATED = object
PAPER_QUARTO = object
PAPER_STATEMENT = object
PAPER_TABLOID = object
PAPER_TABLOID_EXTRA = object
PB_SMALL = 0
PB_USE_TEXTCTRL = 0
PCXHandler = object
PD_APP_MODAL = 0
PD_AUTO_HIDE = 0
PD_CAN_ABORT = 0
PD_CAN_SKIP = 0
PD_ELAPSED_TIME = 0
PD_ESTIMATED_TIME = 0
PD_REMAINING_TIME = 0
PD_SMOOTH = 0
PENSTYLE_BDIAGONAL_HATCH = object
PENSTYLE_CROSSDIAG_HATCH = object
PENSTYLE_CROSS_HATCH = object
PENSTYLE_DOT = object
PENSTYLE_DOT_DASH = object
PENSTYLE_FDIAGONAL_HATCH = object
PENSTYLE_FIRST_HATCH = object
PENSTYLE_HORIZONTAL_HATCH = object
PENSTYLE_INVALID = object
PENSTYLE_LAST_HATCH = object
PENSTYLE_LONG_DASH = object
PENSTYLE_SHORT_DASH = object
PENSTYLE_SOLID = object
PENSTYLE_STIPPLE = object
PENSTYLE_STIPPLE_MASK = object
PENSTYLE_STIPPLE_MASK_OPAQUE = object
PENSTYLE_TRANSPARENT = object
PENSTYLE_USER_DASH = object
PENSTYLE_VERTICAL_HATCH = object
PNGHandler = object
PNG_TYPE_COLOUR = object
PNG_TYPE_GREY = object
PNG_TYPE_GREY_RED = object
PNG_TYPE_PALETTE = object
PNMHandler = object
POPUP_WINDOW = 0
PORTRAIT = object
PORT_BASE = object
PORT_COCOA = object
PORT_DFB = object
PORT_GTK = object
PORT_MAC = object
PORT_MOTIF = object
PORT_MSW = object
PORT_OS2 = object
PORT_UNKNOWN = object
PORT_WINCE = object
PORT_X11 = object
POWER_BATTERY = object
POWER_SOCKET = object
POWER_UNKNOWN = object
PREVIEW_DEFAULT = 0
PREVIEW_FIRST = 0
PREVIEW_GOTO = 0
PREVIEW_LAST = 0
PREVIEW_NEXT = 0
PREVIEW_PREVIOUS = 0
PREVIEW_PRINT = 0
PREVIEW_ZOOM = 0
PRINTBIN_AUTO = object
PRINTBIN_CASSETTE = object
PRINTBIN_DEFAULT = object
PRINTBIN_ENVELOPE = object
PRINTBIN_ENVMANUAL = object
PRINTBIN_FORMSOURCE = object
PRINTBIN_LARGECAPACITY = object
PRINTBIN_LARGEFMT = object
PRINTBIN_LOWER = object
PRINTBIN_MANUAL = object
PRINTBIN_MIDDLE = object
PRINTBIN_ONLYONE = object
PRINTBIN_SMALLFMT = object
PRINTBIN_TRACTOR = object
PRINTBIN_USER = object
PRINTER_CANCELLED = object
PRINTER_ERROR = object
PRINTER_NO_ERROR = object
PRINT_MODE_FILE = object
PRINT_MODE_NONE = object
PRINT_MODE_PREVIEW = object
PRINT_MODE_PRINTER = object
PRINT_MODE_STREAM = object
PRINT_QUALITY_DRAFT = 0
PRINT_QUALITY_HIGH = 0
PRINT_QUALITY_LOW = 0
PRINT_QUALITY_MEDIUM = 0
PageSetupDialog = object
PageSetupDialogData = object
PaintDC = object
PaintEvent = object
Palette = object
PaletteChangedEvent = object
Panel = object
PanelNameStr = bytes()
PaperSize = object
PartRegion = object
PasswordEntryDialog = object
Pen = object
PenCap = object
PenJoin = object
PenList = object
PenStyle = object
PercentOf = object
PickerBase = object
PixelDataBase = object
Platform = ''
PlatformInfo = tuple()
PlatformInformation = object
Point = object
Point2D = object
PointList = object
PointList_iterator = object
PolygonFillMode = object
PopupTransientWindow = object
PopupWindow = object
Port = ''
PortId = object
Position = object
PostEvent = dummy_function
PostScriptDC = object
PowerEvent = object
PowerType = object
PreferencesEditor = object
PreferencesPage = object
PreviewCanvas = object
PreviewControlBar = object
PreviewFrame = object
PreviewFrameModalityKind = object
PreviewFrame_AppModal = object
PreviewFrame_NonModal = object
PreviewFrame_WindowModal = object
PrintAbortDialog = object
PrintBin = object
PrintData = object
PrintDialog = object
PrintDialogData = object
PrintMode = object
PrintOrientation = object
PrintPreview = object
Printer = object
PrinterDC = object
PrinterError = object
Printout = object
Process = object
ProcessEvent = object
ProgressDialog = object
PropagateOnce = object
PropagationDisabler = object
PyApp = object
PyAssertionError = object
PyBitmapDataObject = object
PyCommandEvent = object
PyControl = object
PyDataObjectSimple = tuple()
PyDropTarget = object
PyEvent = object
PyEvtHandler = object
PyNoAppError = object
PyOnDemandOutputWindow = object
PyPanel = object
PyPreviewControlBar = object
PyPreviewFrame = object
PyPrintPreview = object
PyPrintout = object
PyRegionIterator = object
PyScrolledWindow = object
PySimpleApp = object
PySizer = object
PyTextDataObject = object
PyTimer = object
PyValidator = object
PyWindow = object
QueryNewPaletteEvent = object
QueueEvent = dummy_function
RAISED_BORDER = 0
RA_HORIZONTAL = 0
RA_LEFTTORIGHT = 0
RA_SPECIFY_COLS = 0
RA_SPECIFY_ROWS = 0
RA_TOPTOBOTTOM = 0
RA_VERTICAL = 0
RB_GROUP = 0
RB_SINGLE = 0
RED = object
RED_BRUSH = object
RED_PEN = object
RELEASE_NUMBER = 0
REMOVE_LEADING_SPACES = 0
RESERVE_SPACE_EVEN_IF_HIDDEN = object
RESET = 0
RESIZE_BORDER = 0
RETAINED = 0
RIGHT = object
ROLE_NONE = object
ROLE_SYSTEM_ALERT = object
ROLE_SYSTEM_ANIMATION = object
ROLE_SYSTEM_APPLICATION = object
ROLE_SYSTEM_BORDER = object
ROLE_SYSTEM_BUTTONDROPDOWN = object
ROLE_SYSTEM_BUTTONDROPDOWNGRID = object
ROLE_SYSTEM_BUTTONMENU = object
ROLE_SYSTEM_CARET = object
ROLE_SYSTEM_CELL = object
ROLE_SYSTEM_CHARACTER = object
ROLE_SYSTEM_CHART = object
ROLE_SYSTEM_CHECKBUTTON = object
ROLE_SYSTEM_CLIENT = object
ROLE_SYSTEM_CLOCK = object
ROLE_SYSTEM_COLUMN = object
ROLE_SYSTEM_COLUMNHEADER = object
ROLE_SYSTEM_COMBOBOX = object
ROLE_SYSTEM_CURSOR = object
ROLE_SYSTEM_DIAGRAM = object
ROLE_SYSTEM_DIAL = object
ROLE_SYSTEM_DIALOG = object
ROLE_SYSTEM_DOCUMENT = object
ROLE_SYSTEM_DROPLIST = object
ROLE_SYSTEM_EQUATION = object
ROLE_SYSTEM_GRAPHIC = object
ROLE_SYSTEM_GRIP = object
ROLE_SYSTEM_GROUPING = object
ROLE_SYSTEM_HELPBALLOON = object
ROLE_SYSTEM_HOTKEYFIELD = object
ROLE_SYSTEM_INDICATOR = object
ROLE_SYSTEM_LINK = object
ROLE_SYSTEM_LIST = object
ROLE_SYSTEM_LISTITEM = object
ROLE_SYSTEM_MENUBAR = object
ROLE_SYSTEM_MENUITEM = object
ROLE_SYSTEM_MENUPOPUP = object
ROLE_SYSTEM_OUTLINE = object
ROLE_SYSTEM_OUTLINEITEM = object
ROLE_SYSTEM_PAGETAB = object
ROLE_SYSTEM_PAGETABLIST = object
ROLE_SYSTEM_PANE = object
ROLE_SYSTEM_PROGRESSBAR = object
ROLE_SYSTEM_PROPERTYPAGE = object
ROLE_SYSTEM_PUSHBUTTON = object
ROLE_SYSTEM_RADIOBUTTON = object
ROLE_SYSTEM_ROW = object
ROLE_SYSTEM_ROWHEADER = object
ROLE_SYSTEM_SCROLLBAR = object
ROLE_SYSTEM_SEPARATOR = object
ROLE_SYSTEM_SLIDER = object
ROLE_SYSTEM_SOUND = object
ROLE_SYSTEM_SPINBUTTON = object
ROLE_SYSTEM_STATICTEXT = object
ROLE_SYSTEM_STATUSBAR = object
ROLE_SYSTEM_TABLE = object
ROLE_SYSTEM_TEXT = object
ROLE_SYSTEM_TITLEBAR = object
ROLE_SYSTEM_TOOLBAR = object
ROLE_SYSTEM_TOOLTIP = object
ROLE_SYSTEM_WHITESPACE = object
ROLE_SYSTEM_WINDOW = object
ROMAN = 0
RadioBox = object
RadioBoxNameStr = bytes()
RadioButton = object
RadioButtonNameStr = bytes()
RasterOperationMode = object
RealPoint = object
RearrangeCtrl = object
RearrangeDialog = object
RearrangeDialogNameStr = bytes()
RearrangeList = object
RearrangeListNameStr = bytes()
Rect = object
Rect2D = object
RefCounter = object
Region = object
RegionContain = object
RegionIterator = object
RegisterId = dummy_function
Relationship = object
RendererNative = object
RendererVersion = object
RichMessageDialog = object
Right = object
RightOf = object
SB_FLAT = 0
SB_HORIZONTAL = 0
SB_NORMAL = 0
SB_RAISED = 0
SB_SUNKEN = 0
SB_VERTICAL = 0
SCRIPT = 0
SEND_EVENT_POST = 0
SET = object
SETUP = 0
SHAPED = object
SHORT_DASH = 0
SHOW_EFFECT_BLEND = object
SHOW_EFFECT_EXPAND = object
SHOW_EFFECT_MAX = object
SHOW_EFFECT_NONE = object
SHOW_EFFECT_ROLL_TO_BOTTOM = object
SHOW_EFFECT_ROLL_TO_LEFT = object
SHOW_EFFECT_ROLL_TO_RIGHT = object
SHOW_EFFECT_ROLL_TO_TOP = object
SHOW_EFFECT_SLIDE_TO_BOTTOM = object
SHOW_EFFECT_SLIDE_TO_LEFT = object
SHOW_EFFECT_SLIDE_TO_RIGHT = object
SHOW_EFFECT_SLIDE_TO_TOP = object
SHOW_SB_ALWAYS = object
SHOW_SB_DEFAULT = object
SHOW_SB_NEVER = object
SHRINK = object
SHUTDOWN_FORCE = object
SHUTDOWN_LOGOFF = object
SHUTDOWN_POWEROFF = object
SHUTDOWN_REBOOT = object
SIGABRT = object
SIGALRM = object
SIGBUS = object
SIGEMT = object
SIGFPE = object
SIGHUP = object
SIGILL = object
SIGINT = object
SIGKILL = object
SIGNONE = object
SIGPIPE = object
SIGQUIT = object
SIGSEGV = object
SIGSYS = object
SIGTERM = object
SIGTRAP = object
SIMPLE_BORDER = 0
SIZER_FLAG_BITS_MASK = object
SIZE_ALLOW_MINUS_ONE = 0
SIZE_AUTO = 0
SIZE_AUTO_HEIGHT = 0
SIZE_AUTO_WIDTH = 0
SIZE_FORCE = 0
SIZE_FORCE_EVENT = 0
SIZE_NO_ADJUSTMENTS = 0
SIZE_USE_EXISTING = 0
SLANT = 0
SL_AUTOTICKS = 0
SL_BOTH = 0
SL_BOTTOM = 0
SL_HORIZONTAL = 0
SL_INVERSE = 0
SL_LABELS = 0
SL_LEFT = 0
SL_MIN_MAX_LABELS = 0
SL_RIGHT = 0
SL_SELRANGE = 0
SL_TICKS = 0
SL_TOP = 0
SL_VALUE_LABEL = 0
SL_VERTICAL = 0
SMALL_FONT = object
SOLID = 0
SOUTH = object
SPLIT_DRAG_DRAGGING = 0
SPLIT_DRAG_LEFT_DOWN = 0
SPLIT_DRAG_NONE = 0
SPLIT_HORIZONTAL = object
SPLIT_VERTICAL = object
SP_3D = 0
SP_3DBORDER = 0
SP_3DSASH = 0
SP_ARROW_KEYS = 0
SP_BORDER = 0
SP_HORIZONTAL = 0
SP_LIVE_UPDATE = 0
SP_NOBORDER = 0
SP_NOSASH = 0
SP_NO_XP_THEME = 0
SP_PERMIT_UNSPLIT = 0
SP_THIN_SASH = 0
SP_VERTICAL = 0
SP_WRAP = 0
SRC_INVERT = object
STANDARD_CURSOR = object
STATIC_BORDER = 0
STAY_ON_TOP = 0
STB_DEFAULT_STYLE = 0
STB_ELLIPSIZE_END = 0
STB_ELLIPSIZE_MIDDLE = 0
STB_ELLIPSIZE_START = 0
STB_SHOW_TIPS = 0
STB_SIZEGRIP = 0
STIPPLE = 0
STIPPLE_MASK = 0
STIPPLE_MASK_OPAQUE = 0
STOCK_FOR_BUTTON = object
STOCK_NOFLAGS = object
STOCK_WITHOUT_ELLIPSIS = object
STOCK_WITH_ACCELERATOR = object
STOCK_WITH_MNEMONIC = object
STREAM_EOF = object
STREAM_NO_ERROR = object
STREAM_READ_ERROR = object
STREAM_WRITE_ERROR = object
STRETCH_MASK = object
STRETCH_NOT = object
ST_ELLIPSIZE_END = 0
ST_ELLIPSIZE_MIDDLE = 0
ST_ELLIPSIZE_START = 0
ST_NO_AUTORESIZE = 0
SUNKEN_BORDER = 0
SVGFileDC = object
SWISS = 0
SWISS_FONT = object
SYSTEM_MENU = 0
SYS_ANSI_FIXED_FONT = object
SYS_ANSI_VAR_FONT = object
SYS_BORDER_X = object
SYS_BORDER_Y = object
SYS_CAN_DRAW_FRAME_DECORATIONS = object
SYS_CAN_ICONIZE_FRAME = object
SYS_CAPTION_Y = object
SYS_COLOUR_3DDKSHADOW = object
SYS_COLOUR_3DFACE = object
SYS_COLOUR_3DHIGHLIGHT = object
SYS_COLOUR_3DHILIGHT = object
SYS_COLOUR_3DLIGHT = object
SYS_COLOUR_3DSHADOW = object
SYS_COLOUR_ACTIVEBORDER = object
SYS_COLOUR_ACTIVECAPTION = object
SYS_COLOUR_APPWORKSPACE = object
SYS_COLOUR_BACKGROUND = object
SYS_COLOUR_BTNFACE = object
SYS_COLOUR_BTNHIGHLIGHT = object
SYS_COLOUR_BTNHILIGHT = object
SYS_COLOUR_BTNSHADOW = object
SYS_COLOUR_BTNTEXT = object
SYS_COLOUR_CAPTIONTEXT = object
SYS_COLOUR_DESKTOP = object
SYS_COLOUR_FRAMEBK = object
SYS_COLOUR_GRADIENTACTIVECAPTION = object
SYS_COLOUR_GRADIENTINACTIVECAPTION = object
SYS_COLOUR_GRAYTEXT = object
SYS_COLOUR_HIGHLIGHT = object
SYS_COLOUR_HIGHLIGHTTEXT = object
SYS_COLOUR_HOTLIGHT = object
SYS_COLOUR_INACTIVEBORDER = object
SYS_COLOUR_INACTIVECAPTION = object
SYS_COLOUR_INACTIVECAPTIONTEXT = object
SYS_COLOUR_INFOBK = object
SYS_COLOUR_INFOTEXT = object
SYS_COLOUR_LISTBOX = object
SYS_COLOUR_LISTBOXHIGHLIGHTTEXT = object
SYS_COLOUR_LISTBOXTEXT = object
SYS_COLOUR_MENU = object
SYS_COLOUR_MENUBAR = object
SYS_COLOUR_MENUHILIGHT = object
SYS_COLOUR_MENUTEXT = object
SYS_COLOUR_SCROLLBAR = object
SYS_COLOUR_WINDOW = object
SYS_COLOUR_WINDOWFRAME = object
SYS_COLOUR_WINDOWTEXT = object
SYS_CURSOR_X = object
SYS_CURSOR_Y = object
SYS_DCLICK_MSEC = object
SYS_DCLICK_X = object
SYS_DCLICK_Y = object
SYS_DEFAULT_GUI_FONT = object
SYS_DEVICE_DEFAULT_FONT = object
SYS_DRAG_X = object
SYS_DRAG_Y = object
SYS_EDGE_X = object
SYS_EDGE_Y = object
SYS_FRAMESIZE_X = object
SYS_FRAMESIZE_Y = object
SYS_HSCROLL_ARROW_X = object
SYS_HSCROLL_ARROW_Y = object
SYS_HSCROLL_Y = object
SYS_HTHUMB_X = object
SYS_ICONSPACING_X = object
SYS_ICONSPACING_Y = object
SYS_ICON_X = object
SYS_ICON_Y = object
SYS_MENU_Y = object
SYS_MOUSE_BUTTONS = object
SYS_NETWORK_PRESENT = object
SYS_OEM_FIXED_FONT = object
SYS_PENWINDOWS_PRESENT = object
SYS_SCREEN_DESKTOP = object
SYS_SCREEN_NONE = object
SYS_SCREEN_PDA = object
SYS_SCREEN_SMALL = object
SYS_SCREEN_TINY = object
SYS_SCREEN_X = object
SYS_SCREEN_Y = object
SYS_SHOW_SOUNDS = object
SYS_SMALLICON_X = object
SYS_SMALLICON_Y = object
SYS_SWAP_BUTTONS = object
SYS_SYSTEM_FONT = object
SYS_TABLET_PRESENT = object
SYS_VSCROLL_ARROW_X = object
SYS_VSCROLL_ARROW_Y = object
SYS_VSCROLL_X = object
SYS_VTHUMB_Y = object
SYS_WINDOWMIN_X = object
SYS_WINDOWMIN_Y = object
SafeShowMessage = dummy_function
SafeYield = dummy_function
SameAs = object
SaveFileSelector = dummy_function
ScreenDC = object
ScrollBar = object
ScrollBarNameStr = bytes()
ScrollEvent = object
ScrollWinEvent = object
ScrollbarVisibility = object
ScrolledCanvas = object
ScrolledWindow = object
SearchCtrl = object
SearchCtrlNameStr = bytes()
SeekMode = object
SetCursor = dummy_function
SetCursorEvent = object
Setlocale = dummy_function
SettableHeaderColumn = object
Shell = dummy_function
ShowEffect = object
ShowEvent = object
Shutdown = dummy_function
ShutdownFlags = object
Signal = object
SimpleHelpProvider = object
Simplebook = object
SingleChoiceDialog = object
SingleInstanceChecker = object
Size = object
SizeEvent = object
Sizer = object
SizerFlagBits = object
SizerFlags = object
SizerItem = object
SizerItemList = object
SizerItemList_iterator = object
Sleep = dummy_function
Slider = object
SliderNameStr = bytes()
SpinButton = object
SpinCtrl = object
SpinCtrlDouble = object
SpinDoubleEvent = object
SpinEvent = object
SplitMode = object
SplitterEvent = object
SplitterRenderParams = object
SplitterWindow = object
StandardID = object
StandardPaths = object
StaticBitmap = object
StaticBitmapNameStr = bytes()
StaticBox = object
StaticBoxNameStr = bytes()
StaticBoxSizer = object
StaticLine = object
StaticLineNameStr = bytes()
StaticText = object
StaticTextNameStr = bytes()
StatusBar = object
StatusBarNameStr = bytes()
StatusBarPane = object
StdDialogButtonSizer = object
StockCursor = object
StockGDI = object
StockLabelQueryFlag = object
StockPreferencesPage = object
StopWatch = object
StreamBase = object
StreamError = object
Stretch = object
StringCArrayHolder = object
StripMenuCodes = dummy_function
Strip_Accel = 0
Strip_All = 0
Strip_Mnemonics = 0
SysColourChangedEvent = object
SysErrorCode = dummy_function
SysErrorMsg = dummy_function
SystemColour = object
SystemFeature = object
SystemFont = object
SystemMetric = object
SystemOptions = object
SystemScreenType = object
SystemSettings = object
TAB_TRAVERSAL = 0
TBK_BUTTONBAR = 0
TBK_HORZ_LAYOUT = 0
TB_3DBUTTONS = 0
TB_BOTTOM = 0
TB_DEFAULT_STYLE = 0
TB_DOCKABLE = 0
TB_FLAT = 0
TB_HORIZONTAL = 0
TB_HORZ_LAYOUT = 0
TB_HORZ_TEXT = 0
TB_LEFT = 0
TB_NOALIGN = 0
TB_NODIVIDER = 0
TB_NOICONS = 0
TB_NO_TOOLTIPS = 0
TB_RIGHT = 0
TB_TEXT = 0
TB_TOP = 0
TB_VERTICAL = 0
TC_BOTTOM = 0
TC_FIXEDWIDTH = 0
TC_LEFT = 0
TC_MULTILINE = 0
TC_OWNERDRAW = 0
TC_RIGHT = 0
TC_RIGHTJUSTIFY = 0
TC_TOP = 0
TELETYPE = 0
TEXT_ALIGNMENT_CENTER = object
TEXT_ALIGNMENT_CENTRE = object
TEXT_ALIGNMENT_DEFAULT = object
TEXT_ALIGNMENT_JUSTIFIED = object
TEXT_ALIGNMENT_LEFT = object
TEXT_ALIGNMENT_RIGHT = object
TEXT_ATTR_ALIGNMENT = object
TEXT_ATTR_ALL = object
TEXT_ATTR_BACKGROUND_COLOUR = object
TEXT_ATTR_BULLET = object
TEXT_ATTR_BULLET_NAME = object
TEXT_ATTR_BULLET_NUMBER = object
TEXT_ATTR_BULLET_STYLE = object
TEXT_ATTR_BULLET_STYLE_ALIGN_CENTRE = object
TEXT_ATTR_BULLET_STYLE_ALIGN_LEFT = object
TEXT_ATTR_BULLET_STYLE_ALIGN_RIGHT = object
TEXT_ATTR_BULLET_STYLE_ARABIC = object
TEXT_ATTR_BULLET_STYLE_BITMAP = object
TEXT_ATTR_BULLET_STYLE_CONTINUATION = object
TEXT_ATTR_BULLET_STYLE_LETTERS_LOWER = object
TEXT_ATTR_BULLET_STYLE_LETTERS_UPPER = object
TEXT_ATTR_BULLET_STYLE_NONE = object
TEXT_ATTR_BULLET_STYLE_OUTLINE = object
TEXT_ATTR_BULLET_STYLE_PARENTHESES = object
TEXT_ATTR_BULLET_STYLE_PERIOD = object
TEXT_ATTR_BULLET_STYLE_RIGHT_PARENTHESIS = object
TEXT_ATTR_BULLET_STYLE_ROMAN_LOWER = object
TEXT_ATTR_BULLET_STYLE_ROMAN_UPPER = object
TEXT_ATTR_BULLET_STYLE_STANDARD = object
TEXT_ATTR_BULLET_STYLE_SYMBOL = object
TEXT_ATTR_BULLET_TEXT = object
TEXT_ATTR_CHARACTER = object
TEXT_ATTR_CHARACTER_STYLE_NAME = object
TEXT_ATTR_EFFECTS = object
TEXT_ATTR_EFFECT_CAPITALS = object
TEXT_ATTR_EFFECT_DOUBLE_STRIKETHROUGH = object
TEXT_ATTR_EFFECT_EMBOSS = object
TEXT_ATTR_EFFECT_ENGRAVE = object
TEXT_ATTR_EFFECT_NONE = object
TEXT_ATTR_EFFECT_OUTLINE = object
TEXT_ATTR_EFFECT_SHADOW = object
TEXT_ATTR_EFFECT_SMALL_CAPITALS = object
TEXT_ATTR_EFFECT_STRIKETHROUGH = object
TEXT_ATTR_EFFECT_SUBSCRIPT = object
TEXT_ATTR_EFFECT_SUPERSCRIPT = object
TEXT_ATTR_FONT = object
TEXT_ATTR_FONT_ENCODING = object
TEXT_ATTR_FONT_FACE = object
TEXT_ATTR_FONT_FAMILY = object
TEXT_ATTR_FONT_ITALIC = object
TEXT_ATTR_FONT_PIXEL_SIZE = object
TEXT_ATTR_FONT_POINT_SIZE = object
TEXT_ATTR_FONT_SIZE = object
TEXT_ATTR_FONT_STRIKETHROUGH = object
TEXT_ATTR_FONT_UNDERLINE = object
TEXT_ATTR_FONT_WEIGHT = object
TEXT_ATTR_LEFT_INDENT = object
TEXT_ATTR_LINE_SPACING = object
TEXT_ATTR_LINE_SPACING_HALF = object
TEXT_ATTR_LINE_SPACING_NORMAL = object
TEXT_ATTR_LINE_SPACING_TWICE = object
TEXT_ATTR_LIST_STYLE_NAME = object
TEXT_ATTR_OUTLINE_LEVEL = object
TEXT_ATTR_PAGE_BREAK = object
TEXT_ATTR_PARAGRAPH = object
TEXT_ATTR_PARAGRAPH_STYLE_NAME = object
TEXT_ATTR_PARA_SPACING_AFTER = object
TEXT_ATTR_PARA_SPACING_BEFORE = object
TEXT_ATTR_RIGHT_INDENT = object
TEXT_ATTR_TABS = object
TEXT_ATTR_TEXT_COLOUR = object
TEXT_ATTR_URL = object
TEXT_TYPE_ANY = 0
TE_AUTO_URL = 0
TE_BESTWRAP = 0
TE_CENTER = 0
TE_CENTRE = 0
TE_CHARWRAP = 0
TE_DONTWRAP = 0
TE_HT_BEFORE = object
TE_HT_BELOW = object
TE_HT_BEYOND = object
TE_HT_ON_TEXT = object
TE_HT_UNKNOWN = object
TE_LEFT = 0
TE_MULTILINE = 0
TE_NOHIDESEL = 0
TE_NO_VSCROLL = 0
TE_PASSWORD = 0
TE_PROCESS_ENTER = 0
TE_PROCESS_TAB = 0
TE_READONLY = 0
TE_RICH = 0
TE_RICH2 = 0
TE_RIGHT = 0
TE_WORDWRAP = 0
TGAHandler = object
TIFFHandler = object
TILE = object
TIMER_CONTINUOUS = 0
TIMER_ONE_SHOT = 0
TINY_CAPTION = 0
TITLEBAR_BUTTON_CLOSE = object
TITLEBAR_BUTTON_HELP = object
TITLEBAR_BUTTON_ICONIZE = object
TITLEBAR_BUTTON_MAXIMIZE = object
TITLEBAR_BUTTON_RESTORE = object
TOOL_STYLE_BUTTON = object
TOOL_STYLE_CONTROL = object
TOOL_STYLE_SEPARATOR = object
TOP = object
TRANSPARENT = 0
TRANSPARENT_BRUSH = object
TRANSPARENT_PEN = object
TRANSPARENT_WINDOW = 0
TREE_HITTEST_ABOVE = 0
TREE_HITTEST_BELOW = 0
TREE_HITTEST_NOWHERE = 0
TREE_HITTEST_ONITEM = 0
TREE_HITTEST_ONITEMBUTTON = 0
TREE_HITTEST_ONITEMICON = 0
TREE_HITTEST_ONITEMINDENT = 0
TREE_HITTEST_ONITEMLABEL = 0
TREE_HITTEST_ONITEMLOWERPART = 0
TREE_HITTEST_ONITEMRIGHT = 0
TREE_HITTEST_ONITEMSTATEICON = 0
TREE_HITTEST_ONITEMUPPERPART = 0
TREE_HITTEST_TOLEFT = 0
TREE_HITTEST_TORIGHT = 0
TREE_ITEMSTATE_NEXT = 0
TREE_ITEMSTATE_NONE = 0
TREE_ITEMSTATE_PREV = 0
TR_DEFAULT_STYLE = 0
TR_EDIT_LABELS = 0
TR_FULL_ROW_HIGHLIGHT = 0
TR_HAS_BUTTONS = 0
TR_HAS_VARIABLE_ROW_HEIGHT = 0
TR_HIDE_ROOT = 0
TR_LINES_AT_ROOT = 0
TR_MULTIPLE = 0
TR_NO_BUTTONS = 0
TR_NO_LINES = 0
TR_ROW_LINES = 0
TR_SINGLE = 0
TR_TWIST_BUTTONS = 0
TextAttr = object
TextAttrAlignment = object
TextAttrBulletStyle = object
TextAttrEffects = object
TextAttrFlags = object
TextAttrLineSpacing = object
TextCompleter = object
TextCompleterSimple = object
TextCtrl = object
TextCtrlHitTestResult = object
TextCtrlNameStr = bytes()
TextDataObject = object
TextDropTarget = object
TextEntry = object
TextEntryDialog = object
TextEntryDialogStyle = 0
TextUrlEvent = object
TheClipboard = object
TheMimeTypesManager = object
TimeSpan = object
Timer = object
TimerEvent = object
TimerRunner = object
TipWindow = object
TitleBarButton = object
ToggleButton = object
ToolBar = object
ToolBarNameStr = bytes()
ToolBarToolBase = object
ToolBarToolStyle = object
ToolTip = object
Toolbook = object
Top = object
TopLevelWindow = object
Trackable = object
Translations = object
TranslationsLoader = object
TransparentColour = object
Trap = dummy_function
TreeCtrl = object
TreeCtrlNameStr = bytes()
TreeEvent = object
TreeItemData = dummy_function
TreeItemIcon = object
TreeItemIcon_Expanded = object
TreeItemIcon_Max = object
TreeItemIcon_Normal = object
TreeItemIcon_Selected = object
TreeItemIcon_SelectedExpanded = object
TreeItemId = object
Treebook = object
UIActionSimulator = object
UINT16_MAX = 0
UINT32_MAX = 0
UINT64_MAX = 0
UINT8_MAX = 0
UP = object
UPDATE_UI_FROMIDLE = object
UPDATE_UI_NONE = object
UPDATE_UI_PROCESS_ALL = object
UPDATE_UI_PROCESS_SPECIFIED = object
UPDATE_UI_RECURSE = object
URLDataObject = object
USER_ATTENTION_ERROR = 0
USER_ATTENTION_INFO = 0
USER_DASH = 0
USE_ACCESSIBILITY = 0
USE_FSWATCHER = 0
Unconstrained = object
UniChar = object
UpdateUI = object
UpdateUIEvent = object
UpdateUIMode = object
Usleep = dummy_function
VERSION = tuple()
VERSION_STRING = ''
VERTICAL = object
VERTICAL_HATCH = 0
VListBox = object
VListBoxNameStr = bytes()
VSCROLL = 0
VScrolledWindow = object
Validator = object
VarHScrollHelper = object
VarHVScrollHelper = object
VarScrollHelperBase = object
VarVScrollHelper = object
VersionInfo = object
VideoMode = object
VisualAttributes = object
WANTS_CHARS = 0
WEST = object
WHITE = object
WHITE_BRUSH = object
WHITE_PEN = object
WINDING_RULE = object
WINDOW_STYLE_MASK = 0
WINDOW_VARIANT_LARGE = object
WINDOW_VARIANT_MAX = object
WINDOW_VARIANT_MINI = object
WINDOW_VARIANT_NORMAL = object
WINDOW_VARIANT_SMALL = object
WRAPSIZER_DEFAULT_FLAGS = 0
WS_EX_BLOCK_EVENTS = 0
WS_EX_CONTEXTHELP = 0
WS_EX_PROCESS_IDLE = 0
WS_EX_PROCESS_UI_UPDATES = 0
WS_EX_THEMED_BACKGROUND = 0
WS_EX_TRANSIENT = 0
WS_EX_VALIDATE_RECURSIVELY = 0
WXK_ADD = object
WXK_ALT = object
WXK_BACK = object
WXK_CANCEL = object
WXK_CAPITAL = object
WXK_CATEGORY_ARROW = object
WXK_CATEGORY_CUT = object
WXK_CATEGORY_JUMP = object
WXK_CATEGORY_NAVIGATION = object
WXK_CATEGORY_PAGING = object
WXK_CATEGORY_TAB = object
WXK_CLEAR = object
WXK_COMMAND = object
WXK_CONTROL = object
WXK_CONTROL_A = object
WXK_CONTROL_B = object
WXK_CONTROL_C = object
WXK_CONTROL_D = object
WXK_CONTROL_E = object
WXK_CONTROL_F = object
WXK_CONTROL_G = object
WXK_CONTROL_H = object
WXK_CONTROL_I = object
WXK_CONTROL_J = object
WXK_CONTROL_K = object
WXK_CONTROL_L = object
WXK_CONTROL_M = object
WXK_CONTROL_N = object
WXK_CONTROL_O = object
WXK_CONTROL_P = object
WXK_CONTROL_Q = object
WXK_CONTROL_R = object
WXK_CONTROL_S = object
WXK_CONTROL_T = object
WXK_CONTROL_U = object
WXK_CONTROL_V = object
WXK_CONTROL_W = object
WXK_CONTROL_X = object
WXK_CONTROL_Y = object
WXK_CONTROL_Z = object
WXK_DECIMAL = object
WXK_DELETE = object
WXK_DIVIDE = object
WXK_DOWN = object
WXK_END = object
WXK_ESCAPE = object
WXK_EXECUTE = object
WXK_F1 = object
WXK_F10 = object
WXK_F11 = object
WXK_F12 = object
WXK_F13 = object
WXK_F14 = object
WXK_F15 = object
WXK_F16 = object
WXK_F17 = object
WXK_F18 = object
WXK_F19 = object
WXK_F2 = object
WXK_F20 = object
WXK_F21 = object
WXK_F22 = object
WXK_F23 = object
WXK_F24 = object
WXK_F3 = object
WXK_F4 = object
WXK_F5 = object
WXK_F6 = object
WXK_F7 = object
WXK_F8 = object
WXK_F9 = object
WXK_HELP = object
WXK_HOME = object
WXK_INSERT = object
WXK_LBUTTON = object
WXK_LEFT = object
WXK_MBUTTON = object
WXK_MENU = object
WXK_MULTIPLY = object
WXK_NONE = object
WXK_NUMLOCK = object
WXK_NUMPAD0 = object
WXK_NUMPAD1 = object
WXK_NUMPAD2 = object
WXK_NUMPAD3 = object
WXK_NUMPAD4 = object
WXK_NUMPAD5 = object
WXK_NUMPAD6 = object
WXK_NUMPAD7 = object
WXK_NUMPAD8 = object
WXK_NUMPAD9 = object
WXK_NUMPAD_ADD = object
WXK_NUMPAD_BEGIN = object
WXK_NUMPAD_DECIMAL = object
WXK_NUMPAD_DELETE = object
WXK_NUMPAD_DIVIDE = object
WXK_NUMPAD_DOWN = object
WXK_NUMPAD_END = object
WXK_NUMPAD_ENTER = object
WXK_NUMPAD_EQUAL = object
WXK_NUMPAD_F1 = object
WXK_NUMPAD_F2 = object
WXK_NUMPAD_F3 = object
WXK_NUMPAD_F4 = object
WXK_NUMPAD_HOME = object
WXK_NUMPAD_INSERT = object
WXK_NUMPAD_LEFT = object
WXK_NUMPAD_MULTIPLY = object
WXK_NUMPAD_PAGEDOWN = object
WXK_NUMPAD_PAGEUP = object
WXK_NUMPAD_RIGHT = object
WXK_NUMPAD_SEPARATOR = object
WXK_NUMPAD_SPACE = object
WXK_NUMPAD_SUBTRACT = object
WXK_NUMPAD_TAB = object
WXK_NUMPAD_UP = object
WXK_PAGEDOWN = object
WXK_PAGEUP = object
WXK_PAUSE = object
WXK_PRINT = object
WXK_RAW_CONTROL = object
WXK_RBUTTON = object
WXK_RETURN = object
WXK_RIGHT = object
WXK_SCROLL = object
WXK_SELECT = object
WXK_SEPARATOR = object
WXK_SHIFT = object
WXK_SNAPSHOT = object
WXK_SPACE = object
WXK_SPECIAL1 = object
WXK_SPECIAL10 = object
WXK_SPECIAL11 = object
WXK_SPECIAL12 = object
WXK_SPECIAL13 = object
WXK_SPECIAL14 = object
WXK_SPECIAL15 = object
WXK_SPECIAL16 = object
WXK_SPECIAL17 = object
WXK_SPECIAL18 = object
WXK_SPECIAL19 = object
WXK_SPECIAL2 = object
WXK_SPECIAL20 = object
WXK_SPECIAL3 = object
WXK_SPECIAL4 = object
WXK_SPECIAL5 = object
WXK_SPECIAL6 = object
WXK_SPECIAL7 = object
WXK_SPECIAL8 = object
WXK_SPECIAL9 = object
WXK_START = object
WXK_SUBTRACT = object
WXK_TAB = object
WXK_UP = object
WXK_WINDOWS_LEFT = object
WXK_WINDOWS_MENU = object
WXK_WINDOWS_RIGHT = object
WakeUpIdle = dummy_function
Width = object
Window = object
WindowBase = object
WindowCreateEvent = object
WindowDC = object
WindowDestroyEvent = object
WindowDisabler = object
WindowIDRef = object
WindowList = object
WindowList_iterator = object
WindowModalDialogEvent = object
WindowVariant = object
WithImages = object
WrapSizer = object
XOR = object
XPMHandler = object
YELLOW = object
YELLOW_BRUSH = object
YELLOW_PEN = object
YES = 0
YES_DEFAULT = 0
YES_NO = 0
Yield = dummy_function
YieldIfNeeded = dummy_function
ZipFSHandler = object
_wxPyAPI = object
deprecated = dummy_function
deprecatedMsg = dummy_function
pydate2wxdate = dummy_function
testArrayDoubleTypemap = dummy_function
testArrayIntTypemap = dummy_function
testArrayStringTypemap = dummy_function
testColourTypeMap = dummy_function
testCppClone = dummy_function
testIntPtrTypemap = dummy_function
testSizetTypemap = dummy_function
testStringTypemap = dummy_function
testUIntPtrTypemap = dummy_function
testVariantTypeName = dummy_function
testVariantTypemap = dummy_function
version = dummy_function
wxAssertionError = object
wxEVT_ACTIVATE = 0
wxEVT_ACTIVATE_APP = 0
wxEVT_ANY = 0
wxEVT_AUX1_DCLICK = 0
wxEVT_AUX1_DOWN = 0
wxEVT_AUX1_UP = 0
wxEVT_AUX2_DCLICK = 0
wxEVT_AUX2_DOWN = 0
wxEVT_AUX2_UP = 0
wxEVT_BOOKCTRL_PAGE_CHANGED = 0
wxEVT_BOOKCTRL_PAGE_CHANGING = 0
wxEVT_BUTTON = 0
wxEVT_CHAR = 0
wxEVT_CHAR_HOOK = 0
wxEVT_CHECKBOX = 0
wxEVT_CHECKLISTBOX = 0
wxEVT_CHILD_FOCUS = 0
wxEVT_CHOICE = 0
wxEVT_CHOICEBOOK_PAGE_CHANGED = 0
wxEVT_CHOICEBOOK_PAGE_CHANGING = 0
wxEVT_CLOSE_WINDOW = 0
wxEVT_COLLAPSIBLEPANE_CHANGED = 0
wxEVT_COLOURPICKER_CHANGED = 0
wxEVT_COMBOBOX = 0
wxEVT_COMBOBOX_CLOSEUP = 0
wxEVT_COMBOBOX_DROPDOWN = 0
wxEVT_COMMAND_BOOKCTRL_PAGE_CHANGED = 0
wxEVT_COMMAND_BOOKCTRL_PAGE_CHANGING = 0
wxEVT_COMMAND_BUTTON_CLICKED = 0
wxEVT_COMMAND_CHECKBOX_CLICKED = 0
wxEVT_COMMAND_CHECKLISTBOX_TOGGLED = 0
wxEVT_COMMAND_CHOICEBOOK_PAGE_CHANGED = 0
wxEVT_COMMAND_CHOICEBOOK_PAGE_CHANGING = 0
wxEVT_COMMAND_CHOICE_SELECTED = 0
wxEVT_COMMAND_COLLPANE_CHANGED = 0
wxEVT_COMMAND_COLOURPICKER_CHANGED = 0
wxEVT_COMMAND_COMBOBOX_CLOSEUP = 0
wxEVT_COMMAND_COMBOBOX_DROPDOWN = 0
wxEVT_COMMAND_COMBOBOX_SELECTED = 0
wxEVT_COMMAND_DIRPICKER_CHANGED = 0
wxEVT_COMMAND_ENTER = 0
wxEVT_COMMAND_FILEPICKER_CHANGED = 0
wxEVT_COMMAND_FIND = 0
wxEVT_COMMAND_FIND_CLOSE = 0
wxEVT_COMMAND_FIND_NEXT = 0
wxEVT_COMMAND_FIND_REPLACE = 0
wxEVT_COMMAND_FIND_REPLACE_ALL = 0
wxEVT_COMMAND_FONTPICKER_CHANGED = 0
wxEVT_COMMAND_HEADER_BEGIN_REORDER = 0
wxEVT_COMMAND_HEADER_BEGIN_RESIZE = 0
wxEVT_COMMAND_HEADER_CLICK = 0
wxEVT_COMMAND_HEADER_DCLICK = 0
wxEVT_COMMAND_HEADER_DRAGGING_CANCELLED = 0
wxEVT_COMMAND_HEADER_END_REORDER = 0
wxEVT_COMMAND_HEADER_END_RESIZE = 0
wxEVT_COMMAND_HEADER_MIDDLE_CLICK = 0
wxEVT_COMMAND_HEADER_MIDDLE_DCLICK = 0
wxEVT_COMMAND_HEADER_RESIZING = 0
wxEVT_COMMAND_HEADER_RIGHT_CLICK = 0
wxEVT_COMMAND_HEADER_RIGHT_DCLICK = 0
wxEVT_COMMAND_HEADER_SEPARATOR_DCLICK = 0
wxEVT_COMMAND_KILL_FOCUS = 0
wxEVT_COMMAND_LEFT_CLICK = 0
wxEVT_COMMAND_LEFT_DCLICK = 0
wxEVT_COMMAND_LISTBOOK_PAGE_CHANGED = 0
wxEVT_COMMAND_LISTBOOK_PAGE_CHANGING = 0
wxEVT_COMMAND_LISTBOX_DOUBLECLICKED = 0
wxEVT_COMMAND_LISTBOX_SELECTED = 0
wxEVT_COMMAND_LIST_BEGIN_DRAG = 0
wxEVT_COMMAND_LIST_BEGIN_LABEL_EDIT = 0
wxEVT_COMMAND_LIST_BEGIN_RDRAG = 0
wxEVT_COMMAND_LIST_CACHE_HINT = 0
wxEVT_COMMAND_LIST_COL_BEGIN_DRAG = 0
wxEVT_COMMAND_LIST_COL_CLICK = 0
wxEVT_COMMAND_LIST_COL_DRAGGING = 0
wxEVT_COMMAND_LIST_COL_END_DRAG = 0
wxEVT_COMMAND_LIST_COL_RIGHT_CLICK = 0
wxEVT_COMMAND_LIST_DELETE_ALL_ITEMS = 0
wxEVT_COMMAND_LIST_DELETE_ITEM = 0
wxEVT_COMMAND_LIST_END_LABEL_EDIT = 0
wxEVT_COMMAND_LIST_INSERT_ITEM = 0
wxEVT_COMMAND_LIST_ITEM_ACTIVATED = 0
wxEVT_COMMAND_LIST_ITEM_DESELECTED = 0
wxEVT_COMMAND_LIST_ITEM_FOCUSED = 0
wxEVT_COMMAND_LIST_ITEM_MIDDLE_CLICK = 0
wxEVT_COMMAND_LIST_ITEM_RIGHT_CLICK = 0
wxEVT_COMMAND_LIST_ITEM_SELECTED = 0
wxEVT_COMMAND_LIST_KEY_DOWN = 0
wxEVT_COMMAND_MENU_SELECTED = 0
wxEVT_COMMAND_NOTEBOOK_PAGE_CHANGED = 0
wxEVT_COMMAND_NOTEBOOK_PAGE_CHANGING = 0
wxEVT_COMMAND_RADIOBOX_SELECTED = 0
wxEVT_COMMAND_RADIOBUTTON_SELECTED = 0
wxEVT_COMMAND_RIGHT_CLICK = 0
wxEVT_COMMAND_RIGHT_DCLICK = 0
wxEVT_COMMAND_SCROLLBAR_UPDATED = 0
wxEVT_COMMAND_SEARCHCTRL_CANCEL_BTN = 0
wxEVT_COMMAND_SEARCHCTRL_SEARCH_BTN = 0
wxEVT_COMMAND_SET_FOCUS = 0
wxEVT_COMMAND_SLIDER_UPDATED = 0
wxEVT_COMMAND_SPINCTRLDOUBLE_UPDATED = 0
wxEVT_COMMAND_SPINCTRL_UPDATED = 0
wxEVT_COMMAND_SPLITTER_DOUBLECLICKED = 0
wxEVT_COMMAND_SPLITTER_SASH_POS_CHANGED = 0
wxEVT_COMMAND_SPLITTER_SASH_POS_CHANGING = 0
wxEVT_COMMAND_SPLITTER_UNSPLIT = 0
wxEVT_COMMAND_TEXT_COPY = 0
wxEVT_COMMAND_TEXT_CUT = 0
wxEVT_COMMAND_TEXT_ENTER = 0
wxEVT_COMMAND_TEXT_MAXLEN = 0
wxEVT_COMMAND_TEXT_PASTE = 0
wxEVT_COMMAND_TEXT_UPDATED = 0
wxEVT_COMMAND_TEXT_URL = 0
wxEVT_COMMAND_TOGGLEBUTTON_CLICKED = 0
wxEVT_COMMAND_TOOLBOOK_PAGE_CHANGED = 0
wxEVT_COMMAND_TOOLBOOK_PAGE_CHANGING = 0
wxEVT_COMMAND_TOOL_CLICKED = 0
wxEVT_COMMAND_TOOL_DROPDOWN_CLICKED = 0
wxEVT_COMMAND_TOOL_ENTER = 0
wxEVT_COMMAND_TOOL_RCLICKED = 0
wxEVT_COMMAND_TREEBOOK_NODE_COLLAPSED = 0
wxEVT_COMMAND_TREEBOOK_NODE_EXPANDED = 0
wxEVT_COMMAND_TREEBOOK_PAGE_CHANGED = 0
wxEVT_COMMAND_TREEBOOK_PAGE_CHANGING = 0
wxEVT_COMMAND_TREE_BEGIN_DRAG = 0
wxEVT_COMMAND_TREE_BEGIN_LABEL_EDIT = 0
wxEVT_COMMAND_TREE_BEGIN_RDRAG = 0
wxEVT_COMMAND_TREE_DELETE_ITEM = 0
wxEVT_COMMAND_TREE_END_DRAG = 0
wxEVT_COMMAND_TREE_END_LABEL_EDIT = 0
wxEVT_COMMAND_TREE_GET_INFO = 0
wxEVT_COMMAND_TREE_ITEM_ACTIVATED = 0
wxEVT_COMMAND_TREE_ITEM_COLLAPSED = 0
wxEVT_COMMAND_TREE_ITEM_COLLAPSING = 0
wxEVT_COMMAND_TREE_ITEM_EXPANDED = 0
wxEVT_COMMAND_TREE_ITEM_EXPANDING = 0
wxEVT_COMMAND_TREE_ITEM_GETTOOLTIP = 0
wxEVT_COMMAND_TREE_ITEM_MENU = 0
wxEVT_COMMAND_TREE_ITEM_MIDDLE_CLICK = 0
wxEVT_COMMAND_TREE_ITEM_RIGHT_CLICK = 0
wxEVT_COMMAND_TREE_KEY_DOWN = 0
wxEVT_COMMAND_TREE_SEL_CHANGED = 0
wxEVT_COMMAND_TREE_SEL_CHANGING = 0
wxEVT_COMMAND_TREE_SET_INFO = 0
wxEVT_COMMAND_TREE_STATE_IMAGE_CLICK = 0
wxEVT_COMMAND_VLBOX_SELECTED = 0
wxEVT_CONTEXT_MENU = 0
wxEVT_CREATE = 0
wxEVT_DESTROY = 0
wxEVT_DETAILED_HELP = 0
wxEVT_DIRCTRL_FILEACTIVATED = 0
wxEVT_DIRCTRL_SELECTIONCHANGED = 0
wxEVT_DIRPICKER_CHANGED = 0
wxEVT_DISPLAY_CHANGED = 0
wxEVT_DROP_FILES = 0
wxEVT_END_PROCESS = 0
wxEVT_END_SESSION = 0
wxEVT_ENTER_WINDOW = 0
wxEVT_ERASE_BACKGROUND = 0
wxEVT_FILECTRL_FILEACTIVATED = 0
wxEVT_FILECTRL_FILTERCHANGED = 0
wxEVT_FILECTRL_FOLDERCHANGED = 0
wxEVT_FILECTRL_SELECTIONCHANGED = 0
wxEVT_FILEPICKER_CHANGED = 0
wxEVT_FIND = 0
wxEVT_FIND_CLOSE = 0
wxEVT_FIND_NEXT = 0
wxEVT_FIND_REPLACE = 0
wxEVT_FIND_REPLACE_ALL = 0
wxEVT_FONTPICKER_CHANGED = 0
wxEVT_FSWATCHER = 0
wxEVT_HEADER_BEGIN_REORDER = 0
wxEVT_HEADER_BEGIN_RESIZE = 0
wxEVT_HEADER_CLICK = 0
wxEVT_HEADER_DCLICK = 0
wxEVT_HEADER_DRAGGING_CANCELLED = 0
wxEVT_HEADER_END_REORDER = 0
wxEVT_HEADER_END_RESIZE = 0
wxEVT_HEADER_MIDDLE_CLICK = 0
wxEVT_HEADER_MIDDLE_DCLICK = 0
wxEVT_HEADER_RESIZING = 0
wxEVT_HEADER_RIGHT_CLICK = 0
wxEVT_HEADER_RIGHT_DCLICK = 0
wxEVT_HEADER_SEPARATOR_DCLICK = 0
wxEVT_HELP = 0
wxEVT_HIBERNATE = 0
wxEVT_HOTKEY = 0
wxEVT_ICONIZE = 0
wxEVT_IDLE = 0
wxEVT_INIT_DIALOG = 0
wxEVT_JOY_BUTTON_DOWN = 0
wxEVT_JOY_BUTTON_UP = 0
wxEVT_JOY_MOVE = 0
wxEVT_JOY_ZMOVE = 0
wxEVT_KEY_DOWN = 0
wxEVT_KEY_UP = 0
wxEVT_KILL_FOCUS = 0
wxEVT_LEAVE_WINDOW = 0
wxEVT_LEFT_DCLICK = 0
wxEVT_LEFT_DOWN = 0
wxEVT_LEFT_UP = 0
wxEVT_LISTBOOK_PAGE_CHANGED = 0
wxEVT_LISTBOOK_PAGE_CHANGING = 0
wxEVT_LISTBOX = 0
wxEVT_LISTBOX_DCLICK = 0
wxEVT_LIST_BEGIN_DRAG = 0
wxEVT_LIST_BEGIN_LABEL_EDIT = 0
wxEVT_LIST_BEGIN_RDRAG = 0
wxEVT_LIST_CACHE_HINT = 0
wxEVT_LIST_COL_BEGIN_DRAG = 0
wxEVT_LIST_COL_CLICK = 0
wxEVT_LIST_COL_DRAGGING = 0
wxEVT_LIST_COL_END_DRAG = 0
wxEVT_LIST_COL_RIGHT_CLICK = 0
wxEVT_LIST_DELETE_ALL_ITEMS = 0
wxEVT_LIST_DELETE_ITEM = 0
wxEVT_LIST_END_LABEL_EDIT = 0
wxEVT_LIST_INSERT_ITEM = 0
wxEVT_LIST_ITEM_ACTIVATED = 0
wxEVT_LIST_ITEM_DESELECTED = 0
wxEVT_LIST_ITEM_FOCUSED = 0
wxEVT_LIST_ITEM_MIDDLE_CLICK = 0
wxEVT_LIST_ITEM_RIGHT_CLICK = 0
wxEVT_LIST_ITEM_SELECTED = 0
wxEVT_LIST_KEY_DOWN = 0
wxEVT_MAXIMIZE = 0
wxEVT_MENU = 0
wxEVT_MENU_CLOSE = 0
wxEVT_MENU_HIGHLIGHT = 0
wxEVT_MENU_OPEN = 0
wxEVT_MIDDLE_DCLICK = 0
wxEVT_MIDDLE_DOWN = 0
wxEVT_MIDDLE_UP = 0
wxEVT_MOTION = 0
wxEVT_MOUSEWHEEL = 0
wxEVT_MOUSE_CAPTURE_CHANGED = 0
wxEVT_MOUSE_CAPTURE_LOST = 0
wxEVT_MOVE = 0
wxEVT_MOVE_END = 0
wxEVT_MOVE_START = 0
wxEVT_MOVING = 0
wxEVT_NAVIGATION_KEY = 0
wxEVT_NC_PAINT = 0
wxEVT_NOTEBOOK_PAGE_CHANGED = 0
wxEVT_NOTEBOOK_PAGE_CHANGING = 0
wxEVT_NULL = 0
wxEVT_PAINT = 0
wxEVT_PALETTE_CHANGED = 0
wxEVT_POWER_RESUME = 0
wxEVT_POWER_SUSPENDED = 0
wxEVT_POWER_SUSPENDING = 0
wxEVT_POWER_SUSPEND_CANCEL = 0
wxEVT_QUERY_END_SESSION = 0
wxEVT_QUERY_NEW_PALETTE = 0
wxEVT_RADIOBOX = 0
wxEVT_RADIOBUTTON = 0
wxEVT_RIGHT_DCLICK = 0
wxEVT_RIGHT_DOWN = 0
wxEVT_RIGHT_UP = 0
wxEVT_SCROLLBAR = 0
wxEVT_SCROLLWIN_BOTTOM = 0
wxEVT_SCROLLWIN_LINEDOWN = 0
wxEVT_SCROLLWIN_LINEUP = 0
wxEVT_SCROLLWIN_PAGEDOWN = 0
wxEVT_SCROLLWIN_PAGEUP = 0
wxEVT_SCROLLWIN_THUMBRELEASE = 0
wxEVT_SCROLLWIN_THUMBTRACK = 0
wxEVT_SCROLLWIN_TOP = 0
wxEVT_SCROLL_BOTTOM = 0
wxEVT_SCROLL_CHANGED = 0
wxEVT_SCROLL_LINEDOWN = 0
wxEVT_SCROLL_LINEUP = 0
wxEVT_SCROLL_PAGEDOWN = 0
wxEVT_SCROLL_PAGEUP = 0
wxEVT_SCROLL_THUMBRELEASE = 0
wxEVT_SCROLL_THUMBTRACK = 0
wxEVT_SCROLL_TOP = 0
wxEVT_SEARCHCTRL_CANCEL_BTN = 0
wxEVT_SEARCHCTRL_SEARCH_BTN = 0
wxEVT_SET_CURSOR = 0
wxEVT_SET_FOCUS = 0
wxEVT_SHOW = 0
wxEVT_SIZE = 0
wxEVT_SIZING = 0
wxEVT_SLIDER = 0
wxEVT_SPIN = 0
wxEVT_SPINCTRL = 0
wxEVT_SPINCTRLDOUBLE = 0
wxEVT_SPIN_DOWN = 0
wxEVT_SPIN_UP = 0
wxEVT_SPLITTER_DOUBLECLICKED = 0
wxEVT_SPLITTER_SASH_POS_CHANGED = 0
wxEVT_SPLITTER_SASH_POS_CHANGING = 0
wxEVT_SPLITTER_UNSPLIT = 0
wxEVT_SYS_COLOUR_CHANGED = 0
wxEVT_TEXT = 0
wxEVT_TEXT_COPY = 0
wxEVT_TEXT_CUT = 0
wxEVT_TEXT_ENTER = 0
wxEVT_TEXT_MAXLEN = 0
wxEVT_TEXT_PASTE = 0
wxEVT_TEXT_URL = 0
wxEVT_THREAD = 0
wxEVT_TIMER = 0
wxEVT_TOGGLEBUTTON = 0
wxEVT_TOOL = 0
wxEVT_TOOLBOOK_PAGE_CHANGED = 0
wxEVT_TOOLBOOK_PAGE_CHANGING = 0
wxEVT_TOOL_DROPDOWN = 0
wxEVT_TOOL_ENTER = 0
wxEVT_TOOL_RCLICKED = 0
wxEVT_TREEBOOK_NODE_COLLAPSED = 0
wxEVT_TREEBOOK_NODE_EXPANDED = 0
wxEVT_TREEBOOK_PAGE_CHANGED = 0
wxEVT_TREEBOOK_PAGE_CHANGING = 0
wxEVT_TREE_BEGIN_DRAG = 0
wxEVT_TREE_BEGIN_LABEL_EDIT = 0
wxEVT_TREE_BEGIN_RDRAG = 0
wxEVT_TREE_DELETE_ITEM = 0
wxEVT_TREE_END_DRAG = 0
wxEVT_TREE_END_LABEL_EDIT = 0
wxEVT_TREE_GET_INFO = 0
wxEVT_TREE_ITEM_ACTIVATED = 0
wxEVT_TREE_ITEM_COLLAPSED = 0
wxEVT_TREE_ITEM_COLLAPSING = 0
wxEVT_TREE_ITEM_EXPANDED = 0
wxEVT_TREE_ITEM_EXPANDING = 0
wxEVT_TREE_ITEM_GETTOOLTIP = 0
wxEVT_TREE_ITEM_MENU = 0
wxEVT_TREE_ITEM_MIDDLE_CLICK = 0
wxEVT_TREE_ITEM_RIGHT_CLICK = 0
wxEVT_TREE_KEY_DOWN = 0
wxEVT_TREE_SEL_CHANGED = 0
wxEVT_TREE_SEL_CHANGING = 0
wxEVT_TREE_SET_INFO = 0
wxEVT_TREE_STATE_IMAGE_CLICK = 0
wxEVT_UPDATE_UI = 0
wxEVT_VLBOX = 0
wxEVT_WINDOW_MODAL_DIALOG_CLOSED = 0
wxPyDeprecationWarning = object
wxWidgets_version = ''
wxdate2pydate = dummy_function


class PyEventBinder(object):
	def __init__(self, evtType, expectedIDs=0):
		pass
	
	def Bind(self, target, id1, id2, function):
		pass
	
	def Unbind(self, target, id1, id2, handler=None):
		return False
	
	def _getEvtType(self):
		return 0
	
	typeId = property(_getEvtType)


